/*
   ----------------            alien collider.pov               ------------------------
   ----------------              23. march 2016                 ------------------------
   ----------------       copyright by Norbert W. Kern          ------------------------
   ----------------      norbert-werner.kern@t-online.de        ------------------------ 
*/

// to render this scene, you need a mininimum of 32 GB RAM!
// parse time is about 85 min on an Intel i7-5960X 3.0 GHz, 16 threads system

#version 3.7;

global_settings {
        assumed_gamma 2.2
        max_trace_level 4
        noise_generator 2
}        

#include "stdinc.inc"
#include "functions.inc"

#declare camloc = <0.6,2,-5>;
#declare lookat = <0,-0.65,0>;
#declare camang = 65;

camera {
        ultra_wide_angle 
        location camloc
        look_at lookat 
        right x*image_width/image_height 
        up y 
        angle camang
} 
 
#declare fac = 1;

sky_sphere {
        pigment {
                average
                pigment_map {
                        [1      function {max (min (y, 1), 0)} 
                                color_map {
                                        [0      rgb fac*2.35]
                                        [0.96   rgb fac*4.5]
                                        [1      rgb fac*13.5]
                                }
                        ]
                        [1      function {max (min (y, 1), 0)}
                                turbulence 0.2
                                color_map {
                                        [0      rgbt 1]
                                        [0.5    rgbt <fac*0.385,fac*0.77,fac*1.1,1>]
                                }
                                rotate z*-45
                        ]
                }
        }
}

#macro MetalMat (Color)

texture {
	aoi
	texture_map {
		[0      pigment {color srgb Color*1.5}
		        normal {spotted 0.001 scale 0.0001}
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	emission 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {srgb Color}
	                }
                ]
                [0.4    pigment {color srgb 0}
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {0, 1}
	                }
                ]
                [0.6    pigment {color srgb 0}
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {0, 1}
	                }
                ]
		[1      pigment {color srgb Color*1.5}
		        normal {spotted 0.001 scale 0.0001}
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	emission 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {srgb Color}
	                }
                ]
	}        
}

#end

#declare ground = 1;
#declare center = 1;
#declare energy = 1;
#declare shuttl = 1; 
#declare sparks = 1;

//________________________________________________________________________________________________________________________________________________________________

#declare f_radi = function {pattern {radial}}
#declare f_pig1 = function {pattern {crackle metric 19 form <1,0,0>}} 

#declare nicemaps = 
array [163] {                                             
         118,  119,  135,  136,  184,  188,  196,  226,  237,  243,
         250,  263,  284,  290,  291,  320,  379,  395,  396,  419, 
         461,  470,  481,  486,  506,  508,  509,  518,  530,  536,
         541,  553,  554,  557,  562,  567,  584,  595,  602,  605,
         610,  616,  621,  648,  701,  703,  704,  711,  720,  726,
         732,  742,  783,  809,  835,  872,  873,  875,  882,  927,
         934,  952,  953,  956,  967,  985,  999, 1016, 1026, 1072, 
        1074, 1081, 1085, 1107, 1110, 1136, 1140, 1142, 1148, 1149,
        1153, 1175, 1180, 1184, 1193, 1194, 1206, 1207, 1235, 1237, 
        1241, 1243, 1244, 1245, 1247, 1275, 1337, 1338, 1368, 1369,
        1420, 1424, 1434, 1438, 1446, 1476, 1513, 1519, 1520, 1525,
        1530, 1534, 1552, 1571, 1611, 1618, 1646, 1669, 1691, 1703, 
        1707, 1711, 1720, 1725, 1730, 1744, 1748, 1756, 1780, 1807,
        1835, 1847, 1851, 1854, 1857, 1927, 1954, 1961, 1970, 2017, 
        2063, 2122, 2123, 2142, 2203, 2206, 2256, 2300, 2304, 2352,
        2380, 2426, 2428, 2445, 2446, 2456, 2461, 2477, 2485, 2486,
        2488, 2494, 2498
};

#declare mapnum = nicemaps [48-1]; 
 
#macro ColorMapScan (map, mapnum, colnum, mapmax, reverse)    
 
#declare PigScan = 
pigment {
        image_map {png map} 
        warp {repeat y flip y}
}

#if (mapnum > mapmax)
        #declare reverse = 1;       
#end
 
#local I = 0;
#while (I < 1)
        #if (reverse)
                [I      eval_pigment (PigScan, <mapnum/mapmax-1/(mapmax*2),1-I-colnum*0.5,0.5>)]
        #else
                [I      eval_pigment (PigScan, <mapnum/mapmax-1/(mapmax*2),I-colnum*0.5,0.5>)]
        #end
        #local I = I+(1/colnum);
#end
 
#end 

#if (ground)
      
#declare fA = 18;        

// original macro by Samuel T. Benge  Cylinder heightfield macro using eval_pigment  http://news.povray.org/povray.text.scene-files/thread/%3C3941980C.DC99A493%40aol.com%3E/
// hexagonal prism code by Jaime Vives Piqueres  crystals-cluster   http://www.ignorancia.org/en/uploads/zips/crystals-cluster-v1-jvp.zip

#macro Cy_Hf (Cy_Pgmnt, Cy_Rad, Cy_Num, Cy_High, H1_Pgmnt, H2_Pgmnt)  

#declare X = 0; 
#declare Z = 0; 
#declare Tv = 10/Cy_Num; 
#declare Hv = Cy_High; 
#declare R = seed (58728);
#declare Rv = 0;
#declare Tex = pigment {Cy_Pgmnt}
#declare Th1 = pigment {H1_Pgmnt} 
#declare Th2 = pigment {H2_Pgmnt} 
 
#declare r_t = seed (0);
#declare this_width = Tv*Cy_Rad*2;
#declare cap_extra_factor = -0.1;
#declare cap_extra = this_width*cap_extra_factor;
        
#declare pt0 = 0;                                                                                                                                                  
#declare pt1 = <0,0,-this_width*0.5>;
#declare pt2 = vrotate (pt1,(45+30*rand (r_t))*y);                                                                                                                 
#declare pt3 = vrotate (pt1,(105+30*rand (r_t))*y);                                                                                                                
#declare pt4 = vrotate (pt1,(165+30*rand (r_t))*y);                                                                                                                
#declare pt5 = vrotate (pt1,(225+30*rand (r_t))*y);                                                                                                                
#declare pt6 = vrotate (pt1,(285+30*rand (r_t))*y);                                                                                                                              
                                                                                                                                                                   
union {
        #while (Z < 10+Tv)
                #while (X < 10+Tv)
                        #local Cv = eval_pigment (Tex, <X-5,0,Z-5>);
                        #local H1 = eval_pigment (Th1, <X-5,0,Z-5>);
                        #local H2 = eval_pigment (Th2, <X-5,0,Z-5>); 
                        #local Cf = vlength (<Cv.x,Cv.y,Cv.z>);
                        #local Hv2 = Hv*(1+pow (((X-5)*(X-5)+(Z-5)*(Z-5))*0.02, 3)*30);
                        #if (((X-5)*(X-5)+(Z-5)*(Z-5)) < 25) 
                                #declare this_height = Cf*Hv2;
                                #declare pt0b = <-this_width*0.1+this_width*0.2*rand (r_t),this_height+this_width*0.5*0.3,-this_width*0.1+this_width*0.2*rand(r_t)>;                                                                                                                                    
                                #declare pt1b = pt1+pt1*cap_extra+this_height*y;
                                #declare pt2b = pt2+pt2*cap_extra+this_height*y;
                                #declare pt3b = pt3+pt3*cap_extra+this_height*y;
                                #declare pt4b = pt4+pt4*cap_extra+this_height*y;
                                #declare pt5b = pt5+pt5*cap_extra+this_height*y;
                                #declare pt6b = pt6+pt6*cap_extra+this_height*y;
                                mesh {                                                                                                                               
                                        triangle {pt1, pt2, pt0}        // base 
                                        triangle {pt2, pt3, pt0}                
                                        triangle {pt3, pt4, pt0}                
                                        triangle {pt4, pt5, pt0}                
                                        triangle {pt5, pt6, pt0}                
                                        triangle {pt6, pt1, pt0}                                                                                                    
                                        triangle {pt1, pt2, pt2b}       // walls
                                        triangle {pt1, pt2b, pt1b}              
                                        triangle {pt2, pt3, pt3b}               
                                        triangle {pt2, pt3b, pt2b}              
                                        triangle {pt3, pt4, pt4b}               
                                        triangle {pt3, pt4b, pt3b}              
                                        triangle {pt4, pt5, pt5b}               
                                        triangle {pt4, pt5b, pt4b}              
                                        triangle {pt5, pt6, pt6b}               
                                        triangle {pt5, pt6b, pt5b}              
                                        triangle {pt6, pt1, pt1b}               
                                        triangle {pt6, pt1b, pt6b}                                                                                                   
                                        triangle {pt1b, pt2b, pt0b}     // cap  
                                        triangle {pt2b, pt3b, pt0b}             
                                        triangle {pt3b, pt4b, pt0b}             
                                        triangle {pt4b, pt5b, pt0b}             
                                        triangle {pt5b, pt6b, pt0b}             
                                        triangle {pt6b, pt1b, pt0b} 
                                        rotate y*rand (R)*360
                                        MetalMat (<Cv.x,Cv.y,Cv.z>) 
                                        translate <X,-1.8*pow (H1.y*H2.y, 0.5),Z>                                                                                                                                
                                }
                        #end
                        #declare X = X+Tv;
                #end
                #declare X = 0; 
                #declare Z = Z+Tv;
        #end
        translate <-5,0,-5>
}

#end 

Cy_Hf (
        pigment {
                function {f_pig1 (x-f_radi (x,z,y),z-f_radi (x,z,y),y-f_radi (x,z,y))} 
                scale 0.03      
                color_map {ColorMapScan ("2500_colormaps", mapnum, 256, 1250, 0)}
                #local nCount = 0;
                #while (nCount < 20)
                        rotate -fA*z
                        warp {repeat y flip y}
                        #local nCount = nCount+1;
                #end
                rotate x*90
                scale 7.5
                translate z*-1.5
        },
        0.4,   
        1500,  
        0.25,  
        pigment {
                function {f_radi (x,z,y)} 
                scale 0.03      
                color_map {
                        [0.482  rgb 0]
                        [0.49   rgb 1]
                }
                #local nCount = 0;
                #while (nCount < 20)
                        rotate -fA*z
                        warp {repeat y flip y}
                        #local nCount = nCount+1;
                #end
                rotate x*90
                scale 7.5
                translate z*-1.5
        },
        pigment {
                spherical
                color_map {
                        [0.6    rgb 0]
                        [0.67   rgb 1]
                        [0.76   rgb 1]
                        [0.84   rgb 0]
                }
                scale 16
                translate z*-1.5       
        }
)

#end

plane {
        y, -1.5
        texture {
                pigment {color rgb 0}
        }
}

//________________________________________________________________________________________________________________________________________________________________

#if (center)

#macro MetalMat4 (Color)

texture {
	function {f_pig1 (x-f_radi (x,y,z),y-f_radi (x,y,z),z-f_radi (x,y,z))}
	scale 0.04
	texture_map {
	        [0.375  aoi
	                texture_map {
	                	[0      pigment {color srgb Color*1.5}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {srgb Color}
	                                }
                                ]
                                [0.4    pigment {color srgb 0}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {0, 1}
	                                }
                                ]
                                [0.6    pigment {color srgb 0}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {0, 1}
	                                }
                                ]
	                	[1      pigment {color srgb Color*1.5}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {srgb Color}
	                                }
                                ]
	                }
                ]
                [0.385  pigment {color srgb <182+70,9,71-70>/255}
	                normal {granite 0.02 scale 0.001}
	                finish {
	                        brilliance 4
	                        diffuse 0
	                        ambient 0
	                        emission fac*0.5
	                        metallic
	                        specular 0.8
	                        roughness 0.025
	                        reflection {0, 1}
	        	}
	        ]
	        [0.415  pigment {color srgb <182+70,9,71-70>/255}
	                normal {granite 0.02 scale 0.001}
	                finish {
	                        brilliance 4
	                        diffuse 0
	                        ambient 0
	                        emission fac*0.5
	                        metallic
	                        specular 0.8
	                        roughness 0.025
	                        reflection {0, 1}
	        	}
	        ]
	        [0.425  aoi
	                texture_map {
	                	[0      pigment {color srgb Color*1.5}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {srgb Color}
	                                }
                                ]
                                [0.4    pigment {color srgb 0}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {0, 1}
	                                }
                                ]
                                [0.6    pigment {color srgb 0}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {0, 1}
	                                }
                                ]
	                	[1      pigment {color srgb Color*1.5}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {srgb Color}
	                                }
                                ]
	                }
                ]
	        [0.575  aoi
	                texture_map {
	                	[0      pigment {color srgb Color*1.5}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {srgb Color}
	                                }
                                ]
                                [0.4    pigment {color srgb 0}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {0, 1}
	                                }
                                ]
                                [0.6    pigment {color srgb 0}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {0, 1}
	                                }
                                ]
	                	[1      pigment {color srgb Color*1.5}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {srgb Color}
	                                }
                                ]
	                }
                ]
                [0.585  pigment {color srgb <182-70,9,71+70>/255}
	                normal {granite 0.02 scale 0.001}
	                finish {
	                        brilliance 4
	                        diffuse 0
	                        ambient 0
	                        emission fac*0.5
	                        metallic
	                        specular 0.8
	                        roughness 0.025
	                        reflection {0, 1}
	        	}
	        ]
	        [0.615  pigment {color srgb <182-70,9,71+70>/255} 
	                normal {granite 0.02 scale 0.001}
	                finish {
	                        brilliance 4
	                        diffuse 0
	                        ambient 0
	                        emission fac*0.5
	                        metallic
	                        specular 0.8
	                        roughness 0.025
	                        reflection {0, 1}
	        	}
	        ]
	        [0.625  aoi
	                texture_map {
	                	[0      pigment {color srgb Color*1.5}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {srgb Color}
	                                }
                                ]
                                [0.4    pigment {color srgb 0}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {0, 1}
	                                }
                                ]
                                [0.6    pigment {color srgb 0}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {0, 1}
	                                }
                                ]
	                	[1      pigment {color srgb Color*1.5}
	                                finish {
	                                	brilliance 4
	                                	diffuse 0
	                                	ambient 0
	                                	metallic
	                                	specular 0.8
	                                	roughness 0.025
	                                	reflection {srgb Color}
	                                }
                                ]
	                }
                ]
        }            
}

#end 

#declare T3 =
material {
	MetalMat4 (<82,69,71>/255)     
	interior {ior 1.5}
}

//____________________________________________________________________________________________________

// structure element by Tekno Frannansa  abstract random scene  http://evilsuperbrain.com/gallery/misc/index.php?movie=randmin

#include "transforms.inc" 

#declare niceseeds = 
array [14] {                                             
         48,  49, 104, 201, 213, 214, 282, 290, 337, 483, 
        606, 697, 736, 827
};

#declare rs_ = seed (niceseeds [5-1]);
#declare the_seed = seed (niceseeds [5-1]);  

#macro connect_spheres (p0, r0, p1, r1, cin, cout)

#if (sqrt (pow (r0+cin, 2)-pow (cout+cin, 2))+sqrt (pow (r1+cin, 2)-pow (cout+cin, 2)) < vlength (p1-p0))
	#local pp0 = sqrt (pow (r0+cin, 2)-pow (cout+cin, 2))*vnormalize (p1-p0)+p0;
	#local pp1 = sqrt (pow (r1+cin, 2)-pow (cout+cin, 2))*vnormalize (p0-p1)+p1;
	difference {
		merge {
			cylinder {pp0*1.001-0.001*pp1, pp1*1.001-0.001*pp0, cout} 
			cone {p0, 0, pp0, cout+cin}
			cone {p1, 0, pp1, cout+cin}
		}
		merge {
			torus {cout+cin, cin Reorient_Trans (y,p1-p0) translate pp0}
			torus {cout+cin, cin Reorient_Trans (y,p0-p1) translate pp1}
		}
		bounded_by {cone {p0+(pp0-p0)*r0/(r0+cin), (cout+cin)*r0/(r0+cin), p1+(pp1-p1)*r1/(r1+cin), (cout+cin)*r1/(r1+cin)}}
	}
#else
	difference {
		#local dot = vdot (p1-p0,p1-p0);
		#local d = pow (r0+cin, 2)-pow (r1+cin, 2)+dot;
		#local i = p0+(p1-p0)*d/(2*dot);
		#local q = sqrt (pow (r0+cin, 2)-(d*d)/(4*dot));
		merge {
			cone {p0, 0, i*1.001-0.001*p0, q} 
			cone {p1, 0, i*1.001-0.001*p1, q}
		}
		torus {q, cin Reorient_Trans (y, p1-p0) translate i}
		bounded_by {cone {p0+(i-p0)*r0/(r0+cin), q*r0/(r0+cin), p1+(i-p1)*r1/(r1+cin), q*r1/(r1+cin)}}
	}
#end

#end

#declare r_s = rand (the_seed);
#declare plane_dir = vrotate (-y, <-rand (r_s)*45,rand (r_s)*45,0>);
#declare furthest = 0;

#declare set_up =
union {
        sphere {<0,0,0>, 1}
        sphere {<1.56,-0.31,1.02>, 0.53} 
        sphere {<-1.88,-0.01,-0.05>, 0.87}
        sphere {<0.97,-0.27,2.26>, 0.82} 
        sphere {<1.62,0.92,1.91>, 0.69}
        sphere {<-3.92,0.05,0.42>, 0.75} 
        sphere {<-3.15,-0.45,0.70>, 0.56}
        sphere {<0.58,1.13,1.37>, 0.57}
        sphere {<2.14,-1.13,1.44>, 0.46}
        sphere {<1.06,0.69,3.09>, 0.63}
        sphere {<1.36,1.08,3.20>, 0.53}
        sphere {<-3.71,-1.04,1.71>, 0.61}
        sphere {<-4.99,1.26,1.21>, 0.63} 
        sphere {<-3.80,-1.51,1.07>, 0.42}
        sphere {<-3.23,-0.70,-0.72>, 0.52}
        sphere {<-0.24,1.59,1.76>, 0.44} 
        sphere {<0.41,0.46,0.61>, 0.39}
        sphere {<2.27,-1.13,2.52>, 0.42} 
        sphere {<2.02,0.00,1.58>, 0.43}
        sphere {<-0.05,0.72,2.89>, 0.28} 
        sphere {<-0.26,0.88,2.47>, 0.43} 
        sphere {<1.14,2.02,2.97>, 0.38}
        sphere {<2.54,1.16,2.89>, 0.36}
        sphere {<-4.08,-1.08,0.44>, 0.23}
        sphere {<-4.43,-1.77,2.36>, 0.20}
        sphere {<-5.14,0.35,1.42>, 0.20} 
        sphere {<-5.57,1.12,1.80>, 0.15} 
        sphere {<-4.70,-1.22,1.00>, 0.23}
        sphere {<-4.82,-1.70,1.17>, 0.18}
        sphere {<-3.32,-0.25,-0.03>, 0.10}
        sphere {<-3.07,-0.81,0.18>, 0.16}
        sphere {<-0.53,2.05,1.95>, 0.13} 
        sphere {<-0.26,1.04,1.90>, 0.10} 
        sphere {<0.27,0.43,1.17>, 0.05}
        sphere {<0.04,0.72,0.56>, 0.05}
        sphere {<2.54,-1.77,2.55>, 0.03} 
        connect_spheres (<1.56,-0.31,1.02>, 0.53, <0.00,0.00,0.00>, 0.89, 0.49, 0.40)
        connect_spheres (<-1.88,-0.01,-0.05>, 0.87, <0.00,0.00,0.00>, 0.89, 0.75, 0.04)
        connect_spheres (<0.97,-0.27,2.26>, 0.82, <1.56,-0.31,1.02>, 0.53, 0.40, 0.02)
        connect_spheres (<1.62,0.92,1.91>, 0.69, <1.56,-0.31,1.02>, 0.53, 0.40, 0.04)
        connect_spheres (<-3.92,0.05,0.42>, 0.75, <-1.88,-0.01,-0.05>, 0.87, 0.45, 0.43)
        connect_spheres (<-3.15,-0.45,0.70>, 0.56, <-1.88,-0.01,-0.05>, 0.87, 0.46, 0.03)
        connect_spheres (<0.58,1.13,1.37>, 0.57, <0.97,-0.27,2.26>, 0.82, 0.45, 0.36)
        connect_spheres (<2.14,-1.13,1.44>, 0.46, <0.97,-0.27,2.26>, 0.82, 0.25, 0.15)
        connect_spheres (<1.06,0.69,3.09>, 0.63, <1.62,0.92,1.91>, 0.69, 0.38, 0.18)
        connect_spheres (<1.36,1.08,3.20>, 0.53, <1.62,0.92,1.91>, 0.69, 0.48, 0.33)
        connect_spheres (<-3.71,-1.04,1.71>, 0.61, <-3.92,0.05,0.42>, 0.75, 0.58, 0.57)
        connect_spheres (<-4.99,1.26,1.21>, 0.63, <-3.92,0.05,0.42>, 0.75, 0.55, 0.10)
        connect_spheres (<-3.80,-1.51,1.07>, 0.42, <-3.15,-0.45,0.70>, 0.56, 0.33, 0.18)
        connect_spheres (<-3.23,-0.70,-0.72>, 0.52, <-3.15,-0.45,0.70>, 0.56, 0.31, 0.09)
        connect_spheres (<-0.24,1.59,1.76>, 0.44, <0.58,1.13,1.37>, 0.57, 0.29, 0.24)
        connect_spheres (<0.41,0.46,0.61>, 0.39, <0.58,1.13,1.37>, 0.57, 0.38, 0.32)
        connect_spheres (<2.27,-1.13,2.52>, 0.42, <2.14,-1.13,1.44>, 0.46, 0.39, 0.09)
        connect_spheres (<2.02,0.00,1.58>, 0.43, <2.14,-1.13,1.44>, 0.46, 0.36, 0.11)
        connect_spheres (<-0.05,0.72,2.89>, 0.28, <1.06,0.69,3.09>, 0.63, 0.22, 0.10)
        connect_spheres (<-0.26,0.88,2.47>, 0.43, <1.06,0.69,3.09>, 0.63, 0.39, 0.29)
        connect_spheres (<1.14,2.02,2.97>, 0.38, <1.36,1.08,3.20>, 0.53, 0.28, 0.22)
        connect_spheres (<2.54,1.16,2.89>, 0.36, <1.36,1.08,3.20>, 0.53, 0.30, 0.18)
        connect_spheres (<-4.08,-1.08,0.44>, 0.23, <-3.71,-1.04,1.71>, 0.61, 0.22, 0.13)
        connect_spheres (<-4.43,-1.77,2.36>, 0.20, <-3.71,-1.04,1.71>, 0.61, 0.12, 0.08)
        connect_spheres (<-5.14,0.35,1.42>, 0.20, <-4.99,1.26,1.21>, 0.63, 0.10, 0.03)
        connect_spheres (<-5.57,1.12,1.80>, 0.15, <-4.99,1.26,1.21>, 0.63, 0.14, 0.10)
        connect_spheres (<-4.70,-1.22,1.00>, 0.23, <-3.80,-1.51,1.07>, 0.42, 0.15, 0.10)
        connect_spheres (<-4.82,-1.70,1.17>, 0.18, <-3.80,-1.51,1.07>, 0.42, 0.16, 0.09)
        connect_spheres (<-3.32,-0.25,-0.03>, 0.10, <-3.23,-0.70,-0.72>, 0.52, 0.07, 0.06)
        connect_spheres (<-3.07,-0.81,0.18>, 0.16, <-3.23,-0.70,-0.72>, 0.52, 0.16, 0.12)
        connect_spheres (<-0.53,2.05,1.95>, 0.13, <-0.24,1.59,1.76>, 0.44, 0.07, 0.01)
        connect_spheres (<-0.26,1.04,1.90>, 0.10, <-0.24,1.59,1.76>, 0.44, 0.05, 0.02)
        connect_spheres (<0.27,0.43,1.17>, 0.05, <0.41,0.46,0.61>, 0.39, 0.05, 0.02)
        connect_spheres (<0.04,0.72,0.56>, 0.05, <0.41,0.46,0.61>, 0.39, 0.05, 0.02)
        connect_spheres (<2.54,-1.77,2.55>, 0.03, <2.27,-1.13,2.52>, 0.42, 0.02, 0.01)
	rotate z*-90
	rotate y*90
}

union { 
        #declare n = 0;
        #while (n < 5)
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.31,0.6,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.33,1.0,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.35,1.4,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.37,1.8,0> rotate y*n*72 translate <0,0,-1.5>}  
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.35,2.2,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.33,2.6,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.35,3.0,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.37,3.4,0> rotate y*n*72 translate <0,0,-1.5>} 
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.35,3.8,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.33,4.2,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.35,4.6,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.37,5.0,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.35,5.4,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.37,5.8,0> rotate y*n*72 translate <0,0,-1.5>}  
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.35,6.2,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.33,6.6,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.35,7.0,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.37,7.4,0> rotate y*n*72 translate <0,0,-1.5>} 
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.35,7.8,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.33,8.2,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.35,8.6,0> rotate y*n*72 translate <0,0,-1.5>}
                object {set_up translate (max_extent (set_up)+min_extent (set_up))*-0.5 scale 0.06 translate <-0.37,9.0,0> rotate y*n*72 translate <0,0,-1.5>}         
                #declare n = n+1;                     
        #end
        material {T3}
} 

//________________________________________________________________________________________________________________________________________________________________

// f_Circuit function by Tekno Frannansa  crackcircuit  http://203.29.75.35/povray.binaries.scene-files/thread/%3C3c8bf694@news.povray.org%3E/?ttop=281756&toff=600

#declare gnRepeats = 5;
#declare gfRepeatDist = 0.2;
#declare gfWireWidth = 0.006;
#declare nMetric = 19;

#declare f_CircuitWire =
function {
	pigment {
		crackle
		metric nMetric
		color_map {
			[0      rgb 0]
			[1      rgb 1]
		}
	}
}

#declare f_CircuitSolid =
function {
	pigment {
		crackle
		solid
		metric nMetric
		color_map {
			[0      rgb 0]
			[1      rgb 1]
		}
	}
}

#declare f_CircuitRepeated =
function (x,y,z, fOffsetX, fOffsetY, fOffsetZ) {
	#local nRepeat = 0;
	#while (nRepeat < gnRepeats)
		min (f_CircuitWire (x-fOffsetX*nRepeat,y-fOffsetY*nRepeat,z-fOffsetZ*nRepeat).x,
		#local nRepeat = nRepeat+1;
	#end                                 
	1
	#local nRepeat = 0;
	#while (nRepeat < gnRepeats)
		)
		#local nRepeat = nRepeat+1;
	#end                              
}

#declare f_CircuitRepeatedInterface =
function (x,y,z, fAngle) {f_CircuitRepeated (x,y,z, gfRepeatDist*cos (fAngle),0,gfRepeatDist*sin (fAngle))}

#declare f_Circuit =
function {f_CircuitRepeatedInterface (x,y,z, f_CircuitSolid (x,y,z).x*pi*2)}

#declare tWire1 =
texture {
        pigment {
                function {f_pig1 (x-f_radi (x,z,y),z-f_radi (x,z,y),y-f_radi (x,z,y))}
                scale 0.25
                color_map {
                        [0.15   srgb <9,182-30+30,171+30-30>/200]
                        [0.25   srgb <9,182-30-30,171+30+30>/200]
                }                                     
                poly_wave 2
        }
        normal {
                average
                normal_map {
                        [1      function {f_Circuit (x,y,z)}
                                slope_map {
                                        [0      <0,-30>]
                                        [0      <1,30>]
                                        [0.05   <1,-30>]
                                        [0.05   <0,30>]
                                }
                                poly_wave 2
                        ]
                        [1      spotted 0.075 
                                scale 0.001
                        ]
                        [1      pigment_pattern {
                                        crackle 
                                        metric 1 
                                        form <0.6,1,-1> 
                                        scale 0.5
                                        pigment_map {
                                                #declare X = 0;
                                                #declare Y = 255;
                                                #while (X < Y)
                                                        #declare V = X/Y;
                                                        #declare A = 0.1+0.5*V;
                                                        [V      quilted 
                                                                scale 0.1 
                                                                rotate 0*z
                                                                color_map {
                                                                        [A-0.2  rgb 0]
                                                                        [A+0.2  rgb 1]
                                                                }
                                                        ]
                                                        #declare X = X+1;
                                                #end
                                        }
                                        scale 3
                                }
                                1
                        ]
                }
                accuracy 0.001
        }
        finish {
                brilliance 4
                diffuse 0
                ambient 0
                emission fac*0.6
                metallic
                specular 0.8
                roughness 0.025
                reflection 0.75
	}
}

#declare tWire2 =
texture {
        pigment {
                function {f_pig1 (x-f_radi (x,z,y),z-f_radi (x,z,y),y-f_radi (x,z,y))}
                scale 0.25
                color_map {
                        [0.15   srgb <9,182-30+30,171+30-30>/200]
                        [0.25   srgb <9,182-30-30,171+30+30>/200]
                }
                poly_wave 2
        }
        normal {
                average
                normal_map {
                        [1      function {f_Circuit (x,y,z)}
                                slope_map {
                                        [0      <0,-30>]
                                        [0      <1,30>]
                                        [0.05   <1,-30>]
                                        [0.05   <0,30>]
                                }
                                poly_wave 2
                        ]
                        [1      spotted 0.075 
                                scale 0.001
                        ]
                        [1      pigment_pattern {
                                        crackle 
                                        metric 1 
                                        form <0.6,1,-1> 
                                        scale 0.5
                                        pigment_map {
                                                #declare X = 0;
                                                #declare Y = 255;
                                                #while (X < Y)
                                                        #declare V = X/Y;
                                                        #declare A = 0.1+0.5*V;
                                                        [V      quilted 
                                                                scale 0.1 
                                                                rotate 0*z
                                                                color_map {
                                                                        [A-0.2  rgb 0]
                                                                        [A+0.2  rgb 1]
                                                                }
                                                        ]
                                                        #declare X = X+1;
                                                #end
                                        }
                                        scale 3
                                }
                                1
                        ]        
                }
                accuracy 0.001
        }
        finish {
                brilliance 4
                diffuse 0
                ambient 0
                emission fac*0.05
                metallic
                specular 0.8
                roughness 0.025
                reflection 0.75
	}
}

#declare Color = <0.5,0.5,0.5>;

#declare T6 =
material {
	texture {
		function {f_Circuit (x,y,z)}
		texture_map {
			[gfWireWidth    
			        pigment_pattern {
			                average
			                pigment_map {
			                        [1      crackle 
			                                solid 
			                                scale 4
			                                color_map {
			                                        [0.15   rgb 0]
			                                        [0.85   rgb 1]
			                                }
			                        ]
			                        [1      cells
			                        	scale 2
			                                color_map {
			                                        [0.15   rgb 0]
			                                        [0.85   rgb 1]
			                                }
			                        ]
			                }
			        }
			        texture_map {
			                [0      tWire2]
			                [1      tWire1]
			        }
			]
			[gfWireWidth    
			        aoi
	                        texture_map {
	                        	[0      pigment {color srgb Color*1.5}
	                        	        normal {
                                                        average
                                                        normal_map {
                                                                [1      spotted 0.4 
                                                                        scale 0.001
                                                                ]
                                                                [1      pigment_pattern {
                                                                                crackle 
                                                                                metric 1 
                                                                                form <0.6,1,-1> 
                                                                                scale 0.5
                                                                                pigment_map {
                                                                                        #declare X = 0;
                                                                                        #declare Y = 255;
                                                                                        #while (X < Y)
                                                                                                #declare V = X/Y;
                                                                                                #declare A = 0.1+0.5*V;
                                                                                                [V      quilted 
                                                                                                        scale 0.1 
                                                                                                        rotate 0*z
                                                                                                        color_map {
                                                                                                                [A-0.1  rgb 0]
                                                                                                                [A+0.1  rgb 1]
                                                                                                        }
                                                                                                ]
                                                                                                #declare X = X+1;
                                                                                        #end
                                                                                }
                                                                                scale 1
                                                                        }
                                                                        0.3
                                                                ]        
                                                        }
                                                        accuracy 0.001
                                                }
	                                        finish {
	                                        	brilliance 4
	                                        	diffuse 0
	                                        	emission 0
	                                        	metallic
	                                        	specular 0.8
	                                        	roughness 0.025
	                                        	reflection {srgb Color}
	                                        }
                                        ]
                                        [0.4    pigment {color srgb 0}
	                        	        normal {
                                                        average
                                                        normal_map {
                                                                [1      spotted 0.02 
                                                                        scale 0.001
                                                                ]
                                                                [1      pigment_pattern {
                                                                                crackle 
                                                                                metric 1 
                                                                                form <0.6,1,-1> 
                                                                                scale 0.5
                                                                                pigment_map {
                                                                                        #declare X = 0;
                                                                                        #declare Y = 255;
                                                                                        #while (X < Y)
                                                                                                #declare V = X/Y;
                                                                                                #declare A = 0.1+0.5*V;
                                                                                                [V      quilted 
                                                                                                        scale 0.1 
                                                                                                        rotate 0*z
                                                                                                        color_map {
                                                                                                                [A-0.1  rgb 0]
                                                                                                                [A+0.1  rgb 1]
                                                                                                        }
                                                                                                ]
                                                                                                #declare X = X+1;
                                                                                        #end
                                                                                }
                                                                                scale 1
                                                                        }
                                                                        0.3
                                                                ]        
                                                        }
                                                        accuracy 0.001
                                                }
	                                        finish {
	                                        	brilliance 4
	                                        	diffuse 0
	                                        	metallic
	                                        	specular 0.8
	                                        	roughness 0.025
	                                        	reflection {0, 1}
	                                        }
                                        ]
                                        [0.6    pigment {color srgb 0}
	                        	        normal {
                                                        average
                                                        normal_map {
                                                                [1      spotted 0.02 
                                                                        scale 0.001
                                                                ]
                                                                [1      pigment_pattern {
                                                                                crackle 
                                                                                metric 1 
                                                                                form <0.6,1,-1> 
                                                                                scale 0.5
                                                                                pigment_map {
                                                                                        #declare X = 0;
                                                                                        #declare Y = 255;
                                                                                        #while (X < Y)
                                                                                                #declare V = X/Y;
                                                                                                #declare A = 0.1+0.5*V;
                                                                                                [V      quilted 
                                                                                                        scale 0.1 
                                                                                                        rotate 0*z
                                                                                                        color_map {
                                                                                                                [A-0.1  rgb 0]
                                                                                                                [A+0.1  rgb 1]
                                                                                                        }
                                                                                                ]
                                                                                                #declare X = X+1;
                                                                                        #end
                                                                                }
                                                                                scale 1
                                                                        }
                                                                        0.3
                                                                ]        
                                                        }
                                                        accuracy 0.001
                                                }
	                                        finish {
	                                        	brilliance 4
	                                        	diffuse 0
	                                        	metallic
	                                        	specular 0.8
	                                        	roughness 0.025
	                                        	reflection {0, 1}
	                                        }
                                        ]
	                        	[1      pigment {color srgb Color*1.5}
	                        	        normal {
                                                        average
                                                        normal_map {
                                                                [1      spotted 0.4 
                                                                        scale 0.001
                                                                ]
                                                                [1      pigment_pattern {
                                                                                crackle 
                                                                                metric 1 
                                                                                form <0.6,1,-1> 
                                                                                scale 0.5
                                                                                pigment_map {
                                                                                        #declare X = 0;
                                                                                        #declare Y = 255;
                                                                                        #while (X < Y)
                                                                                                #declare V = X/Y;
                                                                                                #declare A = 0.1+0.5*V;
                                                                                                [V      quilted 
                                                                                                        scale 0.1 
                                                                                                        rotate 0*z
                                                                                                        color_map {
                                                                                                                [A-0.1  rgb 0]
                                                                                                                [A+0.1  rgb 1]
                                                                                                        }
                                                                                                ]
                                                                                                #declare X = X+1;
                                                                                        #end
                                                                                }
                                                                                scale 1
                                                                        }
                                                                        0.3
                                                                ]        
                                                        }
                                                        accuracy 0.001
                                                }
	                                        finish {
	                                        	brilliance 4
	                                        	diffuse 0
	                                        	emission 0
	                                        	metallic
	                                        	specular 0.8
	                                        	roughness 0.025
	                                        	reflection {srgb Color}
	                                        }
                                        ]
	                        } 
	                ]
		}
	}
	scale 0.03
	interior {ior 1.5}
}

// normal definition by Robert W. McGregor  ...thanks for all the fish  http://news.povray.org/povray.binaries.images/message/%3Cweb.4951bf16a9fdfb46bd1b3ad10%40news.povray.org%3E/#%3Cweb.4951bf16a9fdfb46bd1b3ad10%40news.povray.org%3E

#declare Bigripple =
normal {
	waves 1
	frequency 6
	turbulence 0.8
	scale <0.5,0.2,0.2>*0.5
	translate -100*z
	rotate -30*y
}

#declare Smallripple =
normal {
	ripples 1
	frequency 3
	turbulence 0.5
	scale <0.35,0.25,0.25>*0.2
	translate 100*z
	rotate -10*z
}

#declare RippleNorm =
normal {
	average
	normal_map {
		[0.8    Smallripple]
		[0.9    Bigripple]
	}
}

#declare N_Ripples =
normal {
	average
	normal_map {
		[1      RippleNorm scale 1]
		[1      RippleNorm scale 0.33]
		[1      RippleNorm scale 0.10]
		[0.5    RippleNorm scale 0.05]
		[0.25   granite 0.1 scale 0.01]
		[0.125  granite 0.05 scale 0.001]
	}
}

#declare T7 =
material {
        texture {
        	pigment {
        		bozo
        		color_map {
        			[0      rgbf <0.625,1,1,1>]
        			[1      rgbf 1]
        		}
        	}
        	finish {
        		diffuse 0
        		ambient 0
        		reflection {0.02, 0.99 fresnel on}
        		conserve_energy
        		specular 0.4
        		roughness 0.0035
        	}
        	normal {N_Ripples scale 25}
        }
	interior {
		ior 1.1
		media {
			emission rgb fac*100
			samples 100
			density {
				bozo
				scale 0.04
				density_map {
					[0      rgb 0]
					[1      rgb <0.625,0.625,1>]
				}
			}
		}
	}
	scale 0.3
}


//__________________________________________________________________________________________________

// Gilles Tran  Submarine and minefield  http://www.oyonale.com/modeles.php?lang=en&page=32
     
#declare Oeil =
union {
        torus {4.5, 0.5}
        difference {
                sphere {0, 4.3}
                box {-5, 5 scale <1,1,0.05>}
                box {-5, 5 scale <1,1,0.05> translate z}
                box {-5, 5 scale <1,1,0.05> translate z*2}
                box {-5, 5 scale <1,1,0.05> translate z*3}
                box {-5, 5 scale <1,1,0.05> translate z*4}
                box {-5, 5 scale <1,1,0.05> translate -z}
                box {-5, 5 scale <1,1,0.05> translate -z*2}
                box {-5, 5 scale <1,1,0.05> translate -z*3}
                box {-5, 5 scale <1,1,0.05> translate -z*4}
                scale <1,0.7,1>
        }
}

#declare Truc =
union {
        torus {1.5, 0.3 rotate z*90 translate -x}
        cylinder {-x,x,1.5}
        superellipsoid {<0.2, 0.2> scale <1.5,2,2.5> translate x*2.5}
        object {Oeil scale 1.5/7 rotate -x*90 translate <2.5,0,-2.5>}
        object {Oeil scale 1.5/7 rotate -x*90 translate <2.5,0,-2.5> scale <1,1,-1>}
        sphere {0, 1.5 scale <0.5,1,1> translate x*4}
        sphere {0, 1.5 scale <0.5,1,1> translate x*16}
        cylinder {x*4,x*16,1.2}
        torus {1.9, 0.1 rotate z*90 translate x*16.5}
        cylinder {x*16.5, x*17.5, 2}
        torus {1.9, 0.1 rotate z*90 translate x*17.5}
        cylinder {x*17.5, x*23, 1.5}
        union {
                torus {0.5, 0.1}
                intersection {
                        torus {2.5, 0.5 rotate x*90} 
                        plane {y, 0 inverse} 
                        plane {x, 0} 
                        translate x*2.5
                }
                torus {0.5, 0.1 translate -x*2.5 rotate z*-30 translate x*2.5 }
                torus {0.5, 0.1 translate -x*2.5 rotate z*-60 translate x*2.5 }
                torus {0.5, 0.1 translate -x*2.5 rotate z*-90 translate x*2.5 }
                union {
                    cylinder {0, 9*x, 0.5}
                    cylinder {2*x, 5*x, 0.7}
                    torus {0.5, 0.2 rotate z*90 translate x*2}
                    torus {0.7, 0.2 scale <0.2,1,1> rotate z*90 translate x*2.3}
                    torus {0.7, 0.2 scale <0.2,1,1> rotate z*90 translate x*2.6}
                    torus {0.7, 0.2 scale <0.2,1,1> rotate z*90 translate x*2.9}
                    torus {0.7, 0.2 scale <0.2,1,1> rotate z*90 translate x*3.2}
                    torus {0.7, 0.2 scale <0.2,1,1> rotate z*90 translate x*3.5}
                    torus {0.7, 0.2 scale <0.2,1,1> rotate z*90 translate x*3.8}
                    torus {0.7, 0.2 scale <0.2,1,1> rotate z*90 translate x*4.1}
                    torus {0.7, 0.2 scale <0.2,1,1> rotate z*90 translate x*4.4}
                    torus {0.7, 0.2 scale <0.2,1,1> rotate z*90 translate x*4.7}
                    torus {0.5, 0.2 rotate z*90 translate x*5}
                    torus {0.5, 0.3 rotate z*90 translate x*8}
                    cone {0, 0.7, x, 0.9 translate x*8}
                    torus {0.9, 0.2 rotate z*90 translate x*9}
                    translate <2.5,2.5,0>
                }
                translate <2.5,2,1.7>
        }
        union {
              torus {0.5, 0.1}
              intersection {
                        torus {2.5, 0.5 rotate x*90} 
                        plane {y, 0 inverse} 
                        plane {x, 0} 
                        translate x*2.5
              }
              torus {0.5,0.1 translate -x*2.5 rotate z*-30 translate x*2.5 }
              torus {0.5,0.1 translate -x*2.5 rotate z*-60 translate x*2.5 }
              torus {0.5,0.1 translate -x*2.5 rotate z*-90 translate x*2.5 }
              union {
                    cylinder {0,9*x,0.5}
                    cylinder {3*x,6*x,0.7}
                    torus{0.5,0.2 rotate z*90 translate x*3}
                    torus{0.7,0.2 scale <0.2,1,1> rotate z*90 translate x*3.3}
                    torus{0.7,0.2 scale <0.2,1,1> rotate z*90 translate x*3.6}
                    torus{0.7,0.2 scale <0.2,1,1> rotate z*90 translate x*3.9}
                    torus{0.7,0.2 scale <0.2,1,1> rotate z*90 translate x*4.2}
                    torus{0.7,0.2 scale <0.2,1,1> rotate z*90 translate x*4.5}
                    torus{0.7,0.2 scale <0.2,1,1> rotate z*90 translate x*4.8}
                    torus{0.7,0.2 scale <0.2,1,1> rotate z*90 translate x*5.1}
                    torus{0.7,0.2 scale <0.2,1,1> rotate z*90 translate x*5.4}
                    torus{0.7,0.2 scale <0.2,1,1> rotate z*90 translate x*5.7}
                    torus{0.5,0.2 rotate z*90 translate x*6}
                    torus{0.5,0.3 rotate z*90 translate x*8}
                    cone{0,0.7,x,0.9 translate x*8}
                    torus{0.9,0.2 rotate z*90 translate x*9}
                    translate <2.5,2.5,0>
                }
                translate <2.5,2,-1.7>
        }
        union {
                superellipsoid {<0.2,0.2> scale <1,1.3,2.6>}
                object {Oeil scale 1/7 rotate -x*90 translate z*-2.6}
                object {Oeil scale 1/7 rotate -x*90 translate z*2.6}
                object {Oeil scale 1/7 rotate y*90 translate <0,1.3,1.7>}
                object {Oeil scale 1/7 rotate y*90 translate <0,1.3,-1.7>}
                cylinder {x, x*3,1}
                torus {1, 0.2 rotate z*90 translate x*3}
                intersection {
                        torus {4.5, 1 rotate x*90} 
                        plane {y, 0 inverse} 
                        plane {x, 0 inverse} 
                        scale <0.5,1,1> 
                        translate <3,-4.5,0>
                }
                torus {1, 0.3 scale <0.5,4,1> translate <3+2.25,-3,0>}
                translate <15,4.5,0>
        }
        #declare Teta = 0;
        #while (Teta < 360)
        union {
                box {<0,-0.1,-0.05>, <12,0.1,0.05> translate <4,1.2,0>}
                cylinder {-x, 2*x, 0.1 translate y*1.5}
                sphere {0, 0.2 translate <20,1.5,0>}
                sphere {0, 0.1 translate <16.8,2,0>}
                sphere {0, 0.1 translate <17.2,2,0> rotate x*10}
                cylinder {x*20, x*23, 0.18 translate y*1.5}
                rotate x*Teta
        }
        #declare Teta = Teta+20;
        #end
        scale 0.09
        rotate z*-90
        rotate y*90 
        MetalMat (<1,1,1>) 
}

//___________________________________________________________________________________________________________________________________

#declare Triangle_ =
union {
        triangle {<-1,0,1>, <0,1,0>, <1,0,1>}
        triangle {<1,0,1>, <0,1,0>, <1,0,-1>}
        triangle {<-1,0,-1>, <0,1,0>, <1,0,-1>}
        triangle {<-1,0,1>, <0,1,0>, <-1,0,-1>}
        scale 0.5
}

#macro TriRing_ (start_y, end_y, step_y) 

union {
        #local step_ang = 6;
        #local pos_y = start_y;
        #while (pos_y <= end_y)
                #local ang = 0;
                #while (ang < 360)
                        object {Triangle_ scale 0.125 rotate <-90,0,0> translate <0,pos_y,-1> rotate <0,ang,0>}
                        #local ang = ang+step_ang;
                #end
                #local pos_y = pos_y+step_y;
        #end
}

#end

// Stefan Maes  http://www.irtc.org/ftp/pub/old-competition/competition-Jun-95/sm_xrays.zip

#declare CapillaryHolder =
difference { 
        union { 
                cylinder {<0,0,0>, <0,0,6.5>, 1.5}
		cylinder {<0,0,6.5>, <0,0,7>, 3}
	}
	cylinder {<0,0,-1>, <0,0,8>, 0.4}
} 

#declare BlackScrew =
difference {
	union { 
                cone {<3.3,0,1.15>, 0.85, <3.45,0,1.15>, 1}
		cone {<3.45,0,1.15>, 1, <3.6,0,1.15>, 0.85}
		cylinder {<3.6,0,1.15>, <3.8,0,1.15>, 0.85}
		cone {<3.8,0,1.15>, 0.85, <3.95,0,1.15>, 1}
		cone {<3.95,0,1.15>, 1, <4.1,0,1.15>, 0.85}
		cylinder {<4.1,0,1.15>, <4.3,0,1.15>, 0.85}
		cone {<4.2,0,1.15>, 0.85, <4.35,0,1.15>, 1}
		cone {<4.35,0,1.15>, 1, <4.5,0,1.15>, 0.85}
	}
	box {<3.3,-0.65,0.5>, <4.7,0.65,1.7>}
	//material {T5}
} 

#declare TopPiece =
union {
	difference { 
                union { 
                        cylinder {<0,0,0>, <0,0,2.3>, 3.5}
			cone {<0,0,2.3>, 3.5, <0,0,3>, 3}
		}
		plane {-z, -3.25 rotate x*55 rotate z*180}
		plane {-z, -3.25 rotate x*55}
		cylinder {<0,0,1>, <0,0,4>, 1.5}
		cylinder {<3.3,0,1.15>, <4,0,1.15>, 1}
	}
        object {BlackScrew}
} 

#declare MidPiece1 = cylinder {<0,0,0>, <0,0,1>, 2.5} 

#declare Ring =
difference { 
        difference { 
                cylinder {<0,0,0>, <0,0,1.5>, 6}
		cylinder {<0,0,-1>, <0,0,3>, 4}
	}
	cylinder {<5,0,0.75>, <7,0,0.75>, 0.5}
	sphere {<6.4,0,0.75>, 0.8}
	cylinder {<5,0,0.75>, <7,0,0.75>, 0.5 rotate z*90}
	sphere {<6.4,0,0.75>, 0.8 rotate z*90}
	cylinder {<5,0,0.75>, <7,0,0.75>, 0.5 rotate z*180}
	sphere {<6.4,0,0.75>, 0.8 rotate z*180}
	cylinder {<5,0,0.75>, <7,0,0.75>, 0.5 rotate z*270}
	sphere {<6.4,0,0.75>, 0.8 rotate z*270}      
} 

#declare Rod =
union { 
        cylinder {<-6,0,0>, <6,0,0>, 0.9}
	sphere {<-6,0,0>, 0.9 scale <0.9,1,1>}
	sphere {<6,0,0>, 0.9 scale <0.9,1,1>}
}

#declare Wires =
difference {
	union { 
                cone {<0,0,  0>, 3.5, <0,0,0.5>,   4}
		cone {<0,0,0.5>,   4, <0,0,  1>, 3.5}
		cone {<0,0,  1>, 3.5, <0,0,1.5>,   4}
		cone {<0,0,1.5>,   4, <0,0,  2>, 3.5}
		cone {<0,0,  2>, 3.5, <0,0,2.5>,   4}
		cone {<0,0,2.5>,   4, <0,0,  3>, 3.5}
		cone {<0,0,  3>, 3.5, <0,0,3.5>,   4}
		cone {<0,0,3.5>,   4, <0,0,  4>, 3.5}
		cone {<0,0,  4>, 3.5, <0,0,4.5>,   4}
		cone {<0,0,4.5>,   4, <0,0,  5>, 3.5}
		cone {<0,0,  5>, 3.5, <0,0,5.5>,   4}
		cone {<0,0,5.5>,   4, <0,0,  6>, 3.5}
		cone {<0,0,  6>, 3.5, <0,0,6.5>,   4}
		cone {<0,0,6.5>,   4, <0,0,  7>, 3.5}
	}
	box {<-3.2,-5,-1>, <3.2,5,8> inverse}
	union {
		cylinder {<-4,0,2>, <4,0,2>, 1}
		cylinder {<-4,0,5>, <4,0,5>, 1}
		box {<-4,-1,2>, <4,1,5>}
	}
} 

#declare HeightAdjust =
union {
	object {Wires}
	object {Ring translate <0,0,1.0> rotate z*12}
	object {Rod translate <0,0,3.4>}
	object {Ring translate <0,0,4.3> rotate z*-39}
} 

#declare MidPiece2 = cylinder {<0,0,0>, <0,0,0.7>, 2.5}

#declare Trapezium =
union {
	difference { 
	        box {<0,-5.5,0>, <4,5.5,3.5>}
		plane {-z, 4.9 rotate x*243 inverse}
		plane {-z, 4.9 rotate x*243 rotate z*180 inverse}
	}
	difference { 
	        plane {-z, 4.9 rotate x*243}
		box {<0,-5.5,0>, <4,5.5,3.5> inverse}
	}
	difference { 
	        plane {-z, 4.9 rotate x*243 rotate z*180}
		box {<0,-5.5,0>, <4,5.5,3.5> inverse}
	}
	translate <0,0,-1000>
} 

#declare XYShifter =
union { 
        box {<8,7.5,0>, <4,-7.5,0.6>}
        cylinder {<-10,0,0.3>, <10,0,0.3>, 1.1}
	difference {
		box {<-12.6,-0.9,-0.9>, <-10,0.9,0.9> rotate x*35}
		cylinder {<-13,0,0>, <-9,0,0>, 0.8}
		translate <0,0,0.3>
	}
	difference {
		box {<12,-0.9,-0.9>, <10,0.9,0.9> rotate x*35}
		cylinder {<13,0,0>, <9,0,0>, 0.8}
		translate <0,0,0.3>
	}      
}

#declare Screw =
difference { 
        cylinder {<0,0,0>, <0,0,0.3>, 1.3}
	box {<-0.3,-1.5,0.15>, <0.3,1.5,0.4>}
}

#declare XAdjust =
union {
	difference { 
	        box {<-10,-10,0>, <10,10,5>}
		cone {<0,0,0>, 12.5, <0,0,5>, 11.3 inverse}
		object {Trapezium translate <4,0,1002.1>}
		object {Trapezium translate <7,0,1002.1>}
		object {Trapezium translate <-10.2,0,1002.1>}
		box {<11,-12,3.7>, <6,12,4.4>}
		cylinder {<0,0,4.6>, <0,0,6>, 1.4 translate <7, 6,0>}
		cylinder {<0,0,4.6>, <0,0,6>, 1.4 translate <7,-6,0>}
		sphere {<0,10.2,3>, 1.25}
	}
	object {BlackScrew rotate z*90 translate <0,5.7,1.85>}
	object {Screw rotate z*15 translate <7,6,4.6>}
	object {Screw rotate z*65 translate <7,-6,4.6>}
	object {XYShifter translate <0,0,3.8>}
} 

#declare XRail1 =
intersection {
	difference { 
	        box {<-14.4,10,-3>, <14.4,8,4.2>}
		cylinder{ 
		        <0,-14.5,0>, <0,14.5,0>, 14.5
			scale <1,1,0.29>
			translate <0,0,5>
		}
	}
	cylinder { 
		<0,-14.5,0>, <0,14.5,0>, 14.5
		scale <1,1,0.29> 
		translate <0,0,3.5>
	}
} 

#declare XRail2 =
intersection {
	difference { 
	        box {<-14.4,10,-3>, <14.4,6.5,4.2>}
		cylinder { 
		        <0,-14.5,0>, <0,14.5,0>, 14.5
			scale <1,1,0.29> 
			translate <0,0,5>
		}
	}
	cylinder { 
	        <0,-14.5,0>, <0,14.5,0>, 14.5
		scale <1,1,.29> 
		translate <0,0,3.5>
	}
} 

#declare SquareScrew =
difference {
	box {<2,-0.9,-0.9>, <0,0.9,0.9> rotate x*23}
	cylinder {<3,0,0>, <-1,0,0>, 0.8}
	translate <0,0,0.3>
} 

#declare XBow =
union {
      difference {
	        union {
	                difference { 
	                        box {<-20,-10,0>, <20,10,4.2>}
		                cylinder {
		                        <0,-14.5,0>, <0,14.5,0>, 14.5
				        scale <1,1,0.29> 
				        translate <0,0,5>
			        }
		        }
	                object {XRail1 translate <0,0,1.4>}
	                object {XRail1 rotate z*180 translate <0,0,1.4>}
	                object {XRail2 translate <0,0,2.8>}
	                object {XRail2 rotate z*180 translate <0,0,2.8>}
	        }
	        cylinder {<0,0,-3>, <0,0,8>, 15.5 inverse}
	        box {<-20,-2,-1.5>, <-16,2,2>}
	        box {< 15,-2,-1.5>, < 20,2,2>}
        } 
        object {SquareScrew translate <15,0,0.1> }
        object {SquareScrew rotate z*180 translate <15,0,0.1>}
} 

#declare YAdjust =
union {
	difference {
		union { 
		        box {<-10,-10,3>, <10,10,5>}
			cylinder{ 
			        <-10,0,0>, <10,0,0>, 10
				scale <1,1,0.2> 
				translate <0,0,3>
			}
		}
		cylinder {<0,0,-5>, <0,0,5>, 12.5 inverse}
		object {Trapezium translate <4,0,1002.1>}
		object {Trapezium translate <7,0,1002.1>}
		object {Trapezium translate <-10.2,0,1002.1>}
		box {<11,-12,3.7>, <6,12,4.4>}
		sphere {<0,10.2,3>, 1.25}
	}
	object {BlackScrew rotate z*90 translate <0,5.7,1.85>}
	object {XYShifter translate <0,0,3.4>}
	rotate z*-90
} 

#declare MidPiece3 =
difference { 
        box {<-9,-9.9,-1>, <9,9.9,2>}
	object {YAdjust}
	object {XRail1 translate <0,0,-1.4>}
	object {XRail1 rotate z*180 translate <0,0,-1.4>}
	object {XRail2}
	object {XRail2 rotate z*180}
	cylinder {<0,0,-5>, <0,0,5>, 12.5 inverse}
} 

#declare YRail1 =
intersection {
	difference { 
	        box {<-18.4,10,-3>, <18.4,8,4.2>}
		cylinder {
		        <0,-18.5,0>, <0,18.5,0>, 18.5
			scale <1,1,0.29> 
			translate <0,0,4>
		}
	}
	cylinder { 
	        <0,-18.5,0>, <0,18.5,0>, 18.5
		scale <1,1,0.29> 
		translate <0,0,2.5>
	}
} 

#declare YRail2 =
intersection {
	difference { 
	        box {<-18.4,10,-3>, <18.4,6.5,4.2>}
		cylinder {
		        <0,-18.5,0>, <0,18.5,0>, 18.5
			scale <1,1,0.29> 
			translate <0,0,4>
		}
	}
	cylinder { 
	        <0,-18.5,0>, <0,18.5,0>, 18.5
		scale <1,1,0.29> 
		translate <0,0,2.5>
	}
}

#declare YBow =
union {
        object {SquareScrew translate <14.8,0,-2.7>}
        object {SquareScrew translate <14.8,0,-2.7> rotate z*180}
        difference {
	        union {
	                difference { 
	                        box {<-20,-10,-3>, <20,10,4.2>}
			        cylinder{ 
			                <0,-18.5,0>, <0,18.5,0>, 18.5
				        scale <1,1,0.29> 
				        translate <0,0,4>
				}
		        }
	                object {YRail1 translate <0,0,1.5>}
	                object {YRail2 translate <0,0,3.0>}
	                object {YRail1 rotate z*180 translate <0,0,1.5>}
	                object {YRail2 rotate z*180 translate <0,0,3.0>}
	        }
	        cylinder {<0,0,-8>, <0,0,8>, 17.5 inverse}
	        box {<-20,-2,-3.5>, <-16,2,-0.5>}
	        box {< 15,-2,-3.5>, < 20,2,-0.5>}
	}
        rotate z*-90
} 

#declare MidPiece4 =
difference { 
        box {<-9,-9.9,-4>, <9,9.9,1.5>}
	object {YBow translate <0,0,-2>}
} 

#declare MidPiece5 =
union {
	cylinder {<0,0,0>, <0,0,1.3>, 10.4}
	cylinder {<0,0,1.3>, <0,0,2>, 7}
} 

#declare ClipBox =
box { 
        <-1.98,-1.98,-1>, <1.98,1.98,7>
	rotate z*45
	translate <19,0,0>
} 

#declare ClipBox2 =
union { 
        object {ClipBox}
	object {ClipBox rotate z*4.5}
} 

#declare ClipBox3 =
union { 
        object {ClipBox2}
	object {ClipBox2 rotate z*9}
	object {ClipBox2 rotate z*18}
	object {ClipBox2 rotate z*27}
	object {ClipBox2 rotate z*36}
} 

#declare ClipBox4 =
union { 
        object {ClipBox3}
	object {ClipBox3 rotate z*45}
	object {ClipBox3 rotate z*90}
	object {ClipBox3 rotate z*135}
	object {ClipBox3 rotate z*180}
	object {ClipBox3 rotate z*225}
	object {ClipBox3 rotate z*270}
	object {ClipBox3 rotate z*315}
} 

#declare FastenRing =
difference {
        union { 
                cone {<0,0,0>, 16.5, <0,0,1>, 17.5}
        	cylinder {<0,0,1>, <0,0,4>, 17.5}
        	cone {<0,0,4>, 17.5, <0,0,5>, 16.5}
	}
        object {ClipBox4}
} 

#declare GonioHead =
union {
        object {FastenRing      translate <0,0,-4>}
        object {FastenRing      translate <0,0,5>}
        object {MidPiece5       translate <0,0,10>}
        object {YBow            translate <0,0,15>}
        object {MidPiece4       translate <0,0,17.2>}
        object {XBow            translate <0,0,17.2>}
        object {MidPiece3       translate <0,0,20>}
        object {YAdjust         translate <0,0,20>}
        object {XAdjust         translate <0,0,24.9>}
        object {MidPiece2       translate <0,0,29.9>}
        object {HeightAdjust    translate <0,0,30.6>}
        object {MidPiece1       translate <0,0,37.6>}
        object {TopPiece        translate <0,0,38.6>}
        object {CapillaryHolder translate <0,0,35.3>}
}

#declare BoltTop_ = object {GonioHead scale 0.121}

//_______________________________________________________________

#declare Eye2_Part1 =
union {
        torus {0.5, 0.25 scale <1,4,1>}
        cylinder {-y*2, 0, 0.75} 
}

#declare Eye2_Part2 = cylinder {0, y*1.75, 0.625 scale <1,0.5,1>}

#declare Eye3 =
union {
        object {Eye2_Part1}    
        object {
                Eye2_Part2
                pigment {color rgbt 0.9}
                finish {ambient 0 diffuse 2 phong 3}   
                interior {
                        media {
                                emission fac*<1,0.1,0.5>*10.667*90
                                density {
                                        spherical
                                        color_map {
                                                [0      rgb 0]
                                                [2/3    rgb <1,0.1,0.5>]
                                                [1      rgb 20]
                                        }
                                        scale 0.5      
                                        translate 0.75*y
                                }
                        }
                }
                hollow
        }     
        scale 0.25
        rotate -90*x
}


#declare Eye4 =
union {
        object {Eye2_Part1}    
        object {
                Eye2_Part2
                pigment {color rgbt 0.9}
                finish {ambient 0 diffuse 2 phong 3}   
                interior {
                        media {
                                emission fac*<0.1,0,1>*10.667*90
                                density {
                                        spherical
                                        color_map {
                                                [0      rgb 0]
                                                [2/3    rgb <0.1,0,1>]
                                                [1      rgb 20]
                                        }
                                        scale 0.5      
                                        translate 0.75*y
                                }
                        }
                }
                hollow
        }     
        scale 0.25
        rotate -90*x
}

//_______________________________________________________________

#macro RoundBox (A, B, Edge)

#local AA = <min (A.x,B.x),min (A.y,B.y),min (A.z,B.z)>;
#local BB = <max (A.x,B.x),max (A.y,B.y),max (A.z,B.z)>;
#local LBF = AA;
#local RBF = <BB.x,AA.y,AA.z>;
#local RBB = <BB.x,AA.y,BB.z>;
#local LBB = <AA.x,AA.y,BB.z>;
#local LTF = <AA.x,BB.y,AA.z>;
#local RTF = <BB.x,BB.y,AA.z>;
#local RTB = BB;
#local LTB = <AA.x,BB.y,BB.z>;

merge {
        sphere {LBF, Edge}
        sphere {RBF, Edge}
        sphere {RBB, Edge}
        sphere {LBB, Edge}
        sphere {LTF, Edge}
        sphere {RTF, Edge}
        sphere {RTB, Edge}
        sphere {LTB, Edge}
        cylinder {LBF, RBF, Edge}
        cylinder {LBB, RBB, Edge}
        cylinder {LTB, RTB, Edge}
        cylinder {LTF, RTF, Edge}
        cylinder {LBF, LTF, Edge}
        cylinder {RBF, RTF, Edge}
        cylinder {RBB, RTB, Edge}
        cylinder {LBB, LTB, Edge}
        cylinder {LTB, LTF, Edge}
        cylinder {LBB, LBF, Edge}
        cylinder {RTB, RTF, Edge}
        cylinder {RBB, RBF, Edge} 
        box {AA-Edge*x, BB+Edge*x}
        box {AA-Edge*y, BB+Edge*y}
        box {AA-Edge*z, BB+Edge*z}
} 
   
#end

// Aaron Gage  Tokomak Fusion Reactor  www.irtc.org/ftp/pub/stills/1998-02-28/amgtorus.zip 

#declare TPlateRadius = 4.75/tan (radians (30));

#declare TexturePlate1 = 
difference {
	union {
		RoundBox (<-0.5,-3.5,-0.1>, <0.5,3.5,0.1>, 0.02)
		superellipsoid {<1,0.4> scale <1/5,1/5,1/9> translate <0.1,1.5,0>}
		superellipsoid {<1,0.4> scale <1/5,1/5,1/9> translate <0.25,-0.75,0>}
		superellipsoid {<1,0.4> scale <1/5,1/5,1/9> translate <0,-3,0>}
		superellipsoid {<1,0.4> scale <1/5,1/5,1/9> translate <-0.2,2.5,0>}
		superellipsoid {<1,0.4> scale <1/4,1/4,1/9> translate <0.25,-2,0>} 
	}
	cylinder {<0.1,1.2,-0.05>, <0.1,1.2,-1>, 0.05}
	cylinder {<0.25,-1.25,-0.05>, <0.25,-1.25,-1>, 0.05}
	cylinder {<0,-2.25,-0.05>, <0,-2.25,-1>, 0.05}
}

#declare Conduit =
merge {
        cylinder {<-0.25,-1.2+0.001,0>, <-0.25,-2-0.001,0>, 0.0625} 
        difference {
                torus {0.105, 0.0625 rotate z*90}
                plane {z*-1, 0 hollow}
                rotate y*180
                translate <-0.25,-1.99-0.205,0.099>
        }
        difference {
                torus {0.1, 0.0625 rotate z*90}
                plane {y, 0 hollow}
                plane {z*-1, 0 hollow}
                translate <-0.25,-1.2,0.1>
        }
        difference {
                torus {0.1, 0.0625 rotate z*90}
                plane {y*-1, 0 hollow}
                plane {z*-1, 0 hollow}
                translate <-0.25,-1.99,0.1>
        }
        difference {
                torus {0.105, 0.0625 rotate z*90}
                plane {z*-1, 0 hollow}
                rotate y*180
                translate <-0.25,-0.79-0.205,0.099>
        }
        cylinder {<-0.25,-1.2+0.001-1.2,0>, <-0.25,-2-0.001-1.2,0>, 0.0625}
        difference {
                torus {0.1, 0.0625 rotate z*90}
                plane {y, 0 hollow}
                plane {z*-1, 0 hollow}
                translate <-0.25,-1.2-1.2,0.1>
        }
        difference {
                torus {0.1, 0.0625 rotate x*90}
                plane {y*-1, 0 hollow}
                plane {x*-1, 0 hollow}
		translate <-0.15,-1.99-1.2,0>
        } 
	cylinder {<-0.1501,-1.99-0.1-1.2,0>, <-0.0499,-1.99-0.1-1.2,0>, 0.0625}
        difference {
                torus {0.1, 0.0625}
                plane {x, 0 hollow}
                plane {z*-1, 0 hollow}
                rotate x*-90
                translate <-0.05,-1.99-1.2,0>
        }
        material {T7}
}

#declare TexturePlate2 = 
union {
        difference {
        	union {
        		RoundBox (<-0.5,-1,-0.1>, <0.5,3.5,0.1>, 0.02)
        		superellipsoid {<1,0.4> scale <1/5,1/5,1/9> translate <0.1,1.5,0>}
        		superellipsoid {<1,0.4> scale <1/5,1/5,1/9> translate <0.25,-0.75,0>}
        		superellipsoid {<1,0.4> scale <1/5,1/5,1/9> translate <-0.2,2.5,0>} 
        	}
        	cylinder {<0.1,1.2,-0.05>, <0.1,1.2,-1>, 0.05}
        	cylinder {<0.25,-1.25,-0.05>, <0.25,-1.25,-1>, 0.05}
        	cylinder {<0,-2.25,-0.05>, <0,-2.25,-1>, 0.05}
        }
        object {Conduit translate <0.1,0,0>}
        object {Truc scale <0.7,1,0.7>*1.01 translate <0.15,-1.11,0.05>}
}

#declare TexturePlate3 = 
union {
        difference {
                object {TexturePlate1 rotate z*180}
                plane {y, -1 hollow}
        }
        object {Conduit translate <0.1,0,0>}
        object {Truc scale <0.7,1,0.7>*1.01 translate <0.15,-1.11,0.05>}
}

#macro UpperTexture (srp)

#declare rp = seed (srp);
union {
        object { // left
                TexturePlate2 material {T6 scale 1/0.12 translate <rand (rp)*10,rand (rp)*10,rand (rp)*10>}
                rotate x*-20
		translate z*-TPlateRadius
		rotate y*degrees (atan2 (0.55/TPlateRadius, 1))
	}
        union {
                object { // left 
                        TexturePlate1 
                        material {T6 scale 1/0.12 translate <rand (rp)*10,rand (rp)*10,rand (rp)*10>} 
	        }
	        object {
	                BoltTop_ 
	                MetalMat (<1,1,1>)
	                rotate y*90
	                scale 0.05 
	                translate <0.45,-2.18,0>
	        }
	        object {
	                Eye3
	                MetalMat (<1,1,1>)
	                scale 0.1
	                translate <0.45,-2.15,-0.12>
	        }
	        object {
	                Eye4
	                MetalMat (<1,1,1>)
	                scale 0.1
	                translate <0.45,-2.21,-0.12>
	        }
                rotate x*-20
	        translate z*-TPlateRadius
	        rotate y*degrees (atan2 (1.65/TPlateRadius, 1))	        
	}
        union {
                object { // right 
                        TexturePlate1 
                        rotate z*180  
                        material {T6 scale 1/0.12 translate <rand (rp)*10,rand (rp)*10,rand (rp)*10>} 
	        }
	        object {
	                BoltTop_
	                MetalMat (<1,1,1>)
	                rotate y*90
	                scale 0.05 
	                translate <0.45,-2.18,0>
	        }
	        object {
	                Eye3
	                MetalMat (<1,1,1>)
	                scale 0.1
	                translate <0.45,-2.15,-0.12>
	        }
	        object {
	                Eye4
	                MetalMat (<1,1,1>)
	                scale 0.1
	                translate <0.45,-2.21,-0.12>
	        }
	        rotate x*-20
	        translate z*-TPlateRadius
	        rotate y*-degrees (atan2 (0.55/TPlateRadius, 1))
	}
        object { // right
                TexturePlate3 material {T6 scale 1/0.12 translate <rand (rp)*10,rand (rp)*10,rand (rp)*10>} 
                rotate x*-20
		translate z*-TPlateRadius
		rotate y*-degrees (atan2 (1.65/TPlateRadius, 1))
	}
}

#end 

#macro UpperTexture2 (srp)

#declare rp = seed (srp);
union {
        object { // left
                TexturePlate2 material {T6 scale 1/0.12 translate <rand (rp)*10,rand (rp)*10,rand (rp)*10>}
                rotate x*-20
		translate z*-TPlateRadius
		rotate y*degrees (atan2 (0.55/TPlateRadius, 1))
	}
        union {
                object { // left 
                        TexturePlate1 
                        material {T6 scale 1/0.12 translate <rand (rp)*10,rand (rp)*10,rand (rp)*10>} 
	        }
                rotate x*-20
	        translate z*-TPlateRadius
	        rotate y*degrees (atan2 (1.65/TPlateRadius, 1))	        
	}
        union {
                object { // right 
                        TexturePlate1 
                        rotate z*180  
                        material {T6 scale 1/0.12 translate <rand (rp)*10,rand (rp)*10,rand (rp)*10>} 
	        }
	        rotate x*-20
	        translate z*-TPlateRadius
	        rotate y*-degrees (atan2 (0.55/TPlateRadius, 1))
	}
        object { // right
                TexturePlate3 material {T6 scale 1/0.12 translate <rand (rp)*10,rand (rp)*10,rand (rp)*10>} 
                rotate x*-20
		translate z*-TPlateRadius
		rotate y*-degrees (atan2 (1.65/TPlateRadius, 1))
	}
}

#end

#declare n = 0;
#while (n < 30)
        union {
        	#declare Loop = 0;
        	#while (Loop < 12)
        	        object { 
        	                #if (n = 0)
        	                        UpperTexture (Loop+n)
        	                #else
        	                        UpperTexture2 (Loop+n)
        	                #end 
        		        rotate y*30*Loop
        	        }
        	        #declare Loop = Loop+1;
        	#end
        	scale <3.9,4.2,3.9>
        	translate <0,52,0>
        	scale 0.03
        	translate <0,n,-1.5>
        }
        #declare n = n+1;
#end 

#end

//________________________________________________________________________________________________________________________________________________________________

#if (energy)

#declare Textur =
material {
        texture {
                pigment {color rgbt 1}
        }
        interior {
                media {
                        emission fac*2
                        samples 80
                        density {
                                cylindrical 
                                turbulence 0.1
                                scale <1,0.02,1> 
                                color_map {
                                        [0      rgb <0,0,0>]
                                        [0.2    rgb <1,0,1>]
                                        [0.4    rgb <0,0,0>]
                                        [0.6    rgb <1,0.1,2>]
                                        [0.9    rgb <0,0,0>]
                                        [1      rgb <0,2,20>]
                                }
                        }
                }
        }
}

sphere {
        <0,0,0>, 1 
        hollow 
        material {Textur} 
        scale <1,50,1>*0.18 
        translate <0,0,-1.5>
} 

#declare pipe =
material {
        texture {
                pigment {color rgbt 1}
        }
        interior {
                ior 1.0
                media {
                        emission fac*20
                        samples 80
                        density {
                                cylindrical 
                                turbulence 0.1
                                scale <1,0.02,1>*0.05 
                                color_map {
                                        [0      rgb <0,0,0>]
                                        [0.2    rgb <0.1,0,0>]
                                        [0.4    rgb <0,0,0>]
                                        [0.6    rgb <0.2,0.1,0.5>]
                                        [0.8    rgb <0,0,0>]
                                        [1      rgb <0,2,20>]
                                }
                        }
                        density {
                                gradient y 
                                turbulence 0.1
                                scale 0.04 
                                color_map {
                                        [0      rgb 0.2]
                                        [0.5    rgb 1.8]
                                        [1      rgb 0.2]
                                }
                        }
                }
        }
}

#declare m = 0;
#while (m < 10)
        cylinder {
                y*0.001, y*5, 0.03 
                hollow 
                material {pipe}
                rotate x*90
                rotate y*(m*36-18) 
                translate <0,0.2,-1.5>
        }
        #declare m = m+1;
#end
 
sphere {
        0, 1
        hollow
        material {
        	texture {
                        pigment {color rgbt 1}
                }
                interior {
                        ior 1.0
                        media { 
                                emission fac*<3,80,150>/255
                                samples 80
                                density {
                                        crackle 
                                        metric 1
                                        color_map {
                                                [0      rgb 60]
                                                [0.03   rgb 0]
                                                [1      rgb 0]
                                        }
                                        scale <1,2,1>
                                        warp {turbulence <0.5,0.75,0.5>}
                                }
                                density {
                                        spherical 
                                        color_map {
                                                [0      rgb 0]
                                                [1      rgb 2]
                                        }
                                }
                        }
                }
        }
        scale 0.2
        translate <0,0.2,-1.5>
}

//____________________________________________________________________________________________________________________________________________

#declare n = 10;
#declare r = 1;
#declare t1 = 0;

#declare f_waves_ =
function {
        pigment {
                average 
                pigment_map {
                        #declare k = 1;
                        #while (k < n+1)                        
                                #declare w = 2*pi/n;           
                                #declare x1 = r*cos (k*w+t1);        
                                #declare y1 = r*sin (k*w+t1);
                                [1      wood 
                                        rotate x*90 
                                        sine_wave
                                        scale 0.24     
                                        translate <x1,0,y1>
                                        color_map {
                                                [0      rgb 0]
                                                [1      rgb 1]
                                        }
                                ]
                                #declare k = k+1; 
                        #end
                }
        }
}

#declare nicemaps = 
array [191] {                                             
          84,  100,  111,  115,  124,  133,  140,  230,  262,  269,
         273,  286,  292,  303,  304,  394,  396,  419,  420,  436,
         445,  446,  450,  451,  486,  502,  503,  527,  535,  537,
         539,  540,  545,  552,  555,  572,  663,  667,  669,  680,
         704,  709,  712,  716,  718,  725,  726,  756,  764,  782,
         783,  808,  813,  831,  879,  887,  909,  941,  967,  973,
        1052, 1061, 1075, 1100, 1114, 1115, 1146, 1218, 1233, 1253,
        1255, 1354, 1362, 1373, 1382, 1419, 1439, 1454, 1470, 1484,
        1489, 1512, 1521, 1523, 1536, 1562, 1578, 1602, 1504, 1617, 
        1624, 1645, 1670, 1709, 1749, 1760, 1772, 1778, 1781, 1786,
        1787, 1788, 1789, 1790, 1799, 1808, 1810, 1912, 1822, 1845,
        1863, 1875, 1891, 1895, 1906, 1913, 1917, 1919, 1930, 1944,
        1953, 1959, 1962, 1967, 1974, 2009, 2027, 2028, 2033, 2063,
        2074, 2075, 2117, 2119, 2123, 2133, 2160, 2161, 2189, 2191,
        2202, 2215, 2216, 2218, 2222, 2228, 2229, 2231, 2286, 2306, 
        2310, 2311, 2316, 2341, 2355, 2356, 2359, 2368, 2372, 2373, 
        2378, 2394, 2395, 2398, 2404, 2405, 2406, 2407, 2410, 2412,
        2413, 2414, 2417, 2421, 2423, 2427, 2432, 2435, 2446, 2458,
        2459, 2461, 2463, 2464, 2465, 2467, 2470, 2471, 2476, 2488,
        2499
};

#declare mapnum = nicemaps [67-1]-1; //13, 160, 38, 169, 187   

intersection {
        height_field {
                function 2000, 2000 {f_waves_ ((x-0.5)*10,(z-0.5)*10,(y-0.5)*10).x}
                translate <-0.5,0,-0.5> 
                scale <10,1,10>
        } 
        cylinder {<0,0.37,0>, <0,0.63,0>, 4.999 translate 0.13*y}
        hollow
        material {
                texture {
                        pigment {color rgbt 1}
                }
                interior {
                        ior 1.0
                        media {
                                emission fac*17
                                samples 80
                                density {
                                        function {f_waves_ (x,y,z).x}
                                        color_map {ColorMapScan ("2500_colormaps", mapnum, 256, 1250, 0)}
                                }
                                density {
                                        crackle 
                                        metric 1
                                        color_map {
                                                [0      rgb 2]
                                                [0.05   rgb 0.025]
                                                [1      rgb 0]
                                        }
                                        warp {turbulence <0.5,0.5,0.5>}
                                        scale 0.1
                                }
                        }
                }
        }
        scale <1,0.5,1>
        translate <0,0,-1.5>
} 

//________________________________________________________________________________________________________________________

// Zeger Knaepen  Cylindrical greebles (+code)  http://news.povray.org/povray.binaries.images/message/%3C4470a2a3%40news.povray.org%3E/#%3C4470a2a3%40news.povray.org%3E  
// Zeger Knaepen  Greeble-macros  http://news.povray.org/povray.binaries.scene-files/thread/%3C44981e90%241%40news.povray.org%3E/  

#declare Seed = seed (441*3);
 
#include "greebles.inc" 

#declare f_rad3 = function {pattern {radial}}
#declare f_pig3 = function {pattern {crackle metric 999 form <0,1.7,-0.8>}}  

#declare fA = 11.25;

#declare norm_cyl =
pigment {    
        function {f_pig3 (x-f_rad3 (x,y,z),y-f_rad3 (x,y,z),z-f_rad3 (x,y,z))} 
        scale 0.048      
        color_map {ColorMapScan ("2500_colormaps", 20-1, 256, 1250, 0)}
        #local nCount = 0;
        #while (nCount < 32)
                rotate -fA*z
                warp {repeat y flip y}
                #local nCount = nCount+1;
        #end
}

#macro MetalMatG (Color)

texture {
	aoi
	texture_map {
		[0      pigment {color srgb Color*1.5} 
		        normal {
		                average
		                normal_map {
		                        [1      pigment_pattern {norm_cyl}
        	                        	0.2
        	                        	triangle_wave
        	                        	accuracy 0.001
                                        ]
                                        [1      spotted 0.4 scale 0.0001]
                                
                                }
                        }
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	emission 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {srgb Color}
	                	irid {
        			        0.1
        			        thickness 0.2
        			        turbulence 1
        		        }	                	
	                }
                ]
                [0.4    pigment {color srgb 0}
		        normal {
		                average
		                normal_map {
		                        [1      pigment_pattern {norm_cyl}
        	                        	0.2
        	                        	triangle_wave
        	                        	accuracy 0.001
                                        ]
                                        [1      spotted 0.1 scale 0.0001]
                                
                                }
                        }
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {0, 1}
	                }
                ]
                [0.6    pigment {color srgb 0} 
		        normal {
		                average
		                normal_map {
		                        [1      pigment_pattern {norm_cyl}
        	                        	0.2
        	                        	triangle_wave
        	                        	accuracy 0.001
                                        ]
                                        [1      spotted 0.1 scale 0.0001]
                                
                                }
                        }
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {0, 1}
	                }
                ]
		[1      pigment {color srgb Color*1.5}
		        normal {
		                average
		                normal_map {
		                        [1      pigment_pattern {norm_cyl}
        	                        	0.2
        	                        	triangle_wave
        	                        	accuracy 0.001
                                        ]
                                        [1      spotted 0.4 scale 0.0001]
                                
                                }
                        }
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	emission 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {srgb Color}
	                	irid {
        			        0.1
        			        thickness 0.2
        			        turbulence 1
        		        }
	                }
                ]
	}        
}

#end 

#declare greebleMat =
material {
        MetalMatG (<1,1,1>*0.55)
        interior {ior 1.5}
}

#declare greebleMat2 =
material {
        MetalMatG (<1,1,1>*0.4)
        interior {ior 1.5}
}

#declare greebleMat3 =
material {
        MetalMatG (<1,1,1>*0.4)
        interior {ior 1.5}
} 

#declare greeble_cyl =
union {
	#declare Detail = 600;
	#declare MaxSegmentLength = 0.1;
	VerdeelCilinder (-2, 22, 1, 0, 360, 10, 0.001, 0.1)
	rotate x*90
	scale 1.5
}

#declare greeble_cyl2 =
union {
	#declare Detail = 20;
	#declare MaxSegmentLength = 0.1;
	VerdeelCilinder (-2, 22, 1, 0, 360, 10, 0.001, 0.15)
	rotate x*90
	scale 1.5
} 
 
// Samuel T. Benge  Late Friday Night Abstract  http://news.povray.org/povray.binaries.images/message/%3C3D2FC863.30107%40caltel.com%3E/#%3C3D2FC863.30107%40caltel.com%3E

#declare itr = 36;

#declare AlienTemple =
function {
        -z
        #local V = 1;
        #while (V < itr)  
                -z+min (
                        cos (atan2 (x,y)*pi*V)/V*sqrt (x*x+y*y)
                        ,cos (sqrt (x*x+y*y)*pi*V)/V
                        ,cos (z*pi*V)/V
                )+0.1
                #local V = 2*V+0.5;
        #end
}

#declare Tat =
material {
        texture {
                pigment {
                        #declare mapnum = 608-1;
                        function {AlienTemple (x,y,z)}       
                        color_map {ColorMapScan ("2500_colormaps", mapnum, 256, 1250, 0)}
                }
	        finish {
	        	brilliance 2
	        	diffuse 0
	        	reflection {1, 1.5 metallic}
	        }
        }
}                
                
#include "CopRobot.inc"  // H.E. Day  Drunk Patrol  http://www.irtc.org/ftp/pub/stills/2000-04-30/drunkpat.zip
#include "w_tower.inc"   // Oliver Harlow  IMT Metropolis Carrier  www.twoflower.fsnet.co.uk/crayonworld

#declare m = 0;
#while (m < 10)
        union {
                isosurface {
                        function {
                                -z
                                #local V = 1;
                                #while (V < itr)  
                                        +min (
                                                cos (atan2 (x,y)*pi*V)/V*sqrt (x*x+y*y)
                                                ,cos (sqrt (x*x+y*y)*pi*V)/V
                                                ,cos (z*pi*V)/V
                                        )+0.1
                                        #local V = 2*V+0.5;
                                #end
                        }
                        accuracy 0.00002
                        max_gradient 14
                        contained_by {sphere {0, 1.5}}
                        material {Tat} 
                        scale <1,-1,2>
                        scale 0.3*<1,1,0.3>
                        translate <0,0,0.25>
                }
                union {
                        object {CopperBot}  
                        scale 0.1
                        translate <0,0.35,-0.01> 
                } 
                #if ((m = 1) | (m = 2) | (m = 9))
                        object {
                                greeble_cyl 
                                scale 0.3*<1,1,0.3>
                                material {greebleMat}
                        }
                #else
                        object {
                                greeble_cyl2 
                                scale 0.3*<1,1,0.3>
                                material {greebleMat2}
                        }
                #end
                object {
                        greeble_cyl2
                        scale 0.1*<0.5,0.5,0.9> 
                        translate <-0.36,-0.36,-1.5>
                }
                object {
                        greeble_cyl2
                        scale 0.1*<0.5,0.5,0.9>
                        rotate z*180 
                        translate <0.36,-0.36,-1.5>
                } 
                object {
                        greeble_cyl2
                        scale 0.1*<0.5,0.5,0.9>
                        rotate z*60 
                        translate <-0.22,-0.45,-1.5>
                }
                object {
                        greeble_cyl2
                        scale 0.1*<0.5,0.5,0.9>
                        rotate z*240 
                        translate <0.22,-0.45,-1.5>
                }                
                object {
                        greeble_cyl2
                        scale 0.1*<0.5,0.5,0.9>
                        rotate z*120 
                        translate <-0.08,-0.5,-1.5>
                }
                object {
                        greeble_cyl2
                        scale 0.1*<0.5,0.5,0.9>
                        rotate z*300 
                        translate <0.08,-0.5,-1.5>
                }                
                object {
                        greeble_cyl2
                        scale 0.3*<1,1,0.3>
                        rotate y*90
                        translate <-1.5,0,3.5>
                        material {greebleMat3}
                }
                object {
                        greeble_cyl2
                        scale 0.1*<0.5,0.5,0.9> 
                        rotate z*240
                        translate <0.43,0.18,-1.5>
                        rotate y*90
                        translate <1,0,3.5>
                        material {greebleMat3}
                }
                object {
                        greeble_cyl2
                        scale 0.1*<0.5,0.5,0.9> 
                        rotate z*120                        
                        translate <0.36,0.36,-1.5> 
                        rotate y*90
                        translate <1,0,3.5>
                        material {greebleMat3}
                }
                object {
                        greeble_cyl2
                        scale 0.1*<0.5,0.5,0.9> 
                        translate <0.5,0,-1.5>
                        rotate y*90
                        translate <1,0,3.5>
                        material {greebleMat3}
                }
                object {
                        greeble_cyl2
                        scale 0.3*<1,1,0.3>
                        rotate y*90
                        translate <1,0,5>
                        material {greebleMat3}
                }
                object {
                        greeble_cyl2
                        scale 0.3*<1,1,0.3>
                        rotate y*90
                        translate <1,0.9,5>
                        material {greebleMat3}
                }
                object {
                        greeble_cyl2
                        scale 0.3*<1,1,0.3>
                        rotate y*90
                        translate <1,1.8,5>
                        material {greebleMat3}
                }                  
                object {
                        greeble_cyl2
                        scale 0.3*<1,1,0.3>
                        rotate y*90
                        translate <-1.9,0,5>
                        material {greebleMat3}
                }
                object {
                        greeble_cyl2
                        scale 0.3*<1,1,0.3>
                        rotate y*90
                        translate <-1.9,0.9,5>
                        material {greebleMat3}
                }
                object {
                        greeble_cyl2
                        scale 0.3*<1,1,0.3>
                        rotate y*90
                        translate <-1.9,1.8,5>
                        material {greebleMat3}
                }
                material {greebleMat}
                rotate <0,90,90>
                rotate y*-90
                translate y*4
                rotate x*90
                rotate y*(m*36-18) 
                translate <0,0.2,-1.5>
        }
        #declare m = m+1;
#end 

#declare m = 0;
#while (m < 10)
        object {
                w_tower
                rotate <0,110,0> 
                rotate <0,90,90>
                rotate y*-90
                translate y*5
                rotate x*90
                rotate y*(m*36-26) 
                translate <0,1.45,-1.5>
        } 
        object {
                w_tower
                rotate <0,70,0> 
                rotate <0,90,90>
                rotate y*-90
                translate y*5
                rotate x*90
                rotate y*(m*36-10) 
                translate <0,1.45,-1.5>
        }
        #declare m = m+1;
#end 

#end

//_______________________________________________________________________________________

#if (shuttl) 

#macro LED_ (LEDcol)

#declare Eye2_Part1 =
union {
        torus {0.5, 0.25 scale <1,4,1>}
        cylinder {-y*2, 0, 0.75} 
}

#declare Eye2_Part2 = cylinder {0, y*1.75, 0.625 scale <1,0.5,1>}

union {
        object {Eye2_Part1}    
        object {
                Eye2_Part2
                pigment {color rgbt 0.9}
                finish {ambient 0 diffuse 2 phong 3}   
                interior {
                        media {
                                emission LEDcol*1000
                                density {
                                        spherical
                                        color_map {
                                                [0      rgb 0]
                                                [2/3    rgb LEDcol]
                                                [1      rgb 20]
                                        }
                                        scale 0.5      
                                        translate 0.75*y
                                }
                        }
                }
                hollow
        } 
        MetalMat (<1,1,1>)
}

#end 

#declare f_rad_l = function {pattern {radial}}
#declare f_pig_l = function {pattern {crackle metric 999 form <0,1.7,-0.8>}}  

#declare fA = 11.25;

#declare norm_cyl =
pigment {    
        function {f_pig_l (x-f_rad_l (x,y,z),y-f_rad_l (x,y,z),z-f_rad_l (x,y,z))} 
        scale 0.048      
        color_map {ColorMapScan ("2500_colormaps", 20-1, 256, 1250, 0)}
        #local nCount = 0;
        #while (nCount < 32)
                rotate -fA*z
                warp {repeat y flip y}
                #local nCount = nCount+1;
        #end
}

#macro MetalMatG (Color)

texture {
	aoi
	texture_map {
		[0      pigment {color srgb Color*1.5} 
		        normal {
		                average
		                normal_map {
		                        [1      pigment_pattern {norm_cyl}
        	                        	0.2
        	                        	triangle_wave
        	                        	accuracy 0.001
                                        ]
                                        [1      spotted 0.4 scale 0.0001]
                                
                                }
                        }
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	emission 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {srgb Color}
	                	irid {
        			        0.1
        			        thickness 0.2
        			        turbulence 1
        		        }	                	
	                }
                ]
                [0.4    pigment {color srgb 0}
		        normal {
		                average
		                normal_map {
		                        [1      pigment_pattern {norm_cyl}
        	                        	0.2
        	                        	triangle_wave
        	                        	accuracy 0.001
                                        ]
                                        [1      spotted 0.1 scale 0.0001]
                                
                                }
                        }
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {0, 1}
	                }
                ]
                [0.6    pigment {color srgb 0} 
		        normal {
		                average
		                normal_map {
		                        [1      pigment_pattern {norm_cyl}
        	                        	0.2
        	                        	triangle_wave
        	                        	accuracy 0.001
                                        ]
                                        [1      spotted 0.1 scale 0.0001]
                                
                                }
                        }
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {0, 1}
	                }
                ]
		[1      pigment {color srgb Color*1.5}
		        normal {
		                average
		                normal_map {
		                        [1      pigment_pattern {norm_cyl}
        	                        	0.2
        	                        	triangle_wave
        	                        	accuracy 0.001
                                        ]
                                        [1      spotted 0.4 scale 0.0001]
                                
                                }
                        }
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	emission 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {srgb Color}
	                	irid {
        			        0.1
        			        thickness 0.2
        			        turbulence 1
        		        }
	                }
                ]
	}        
}

#end 

#declare greebleMat =
material {
        MetalMatG (<1,1,1>*0.55)
        interior {ior 1.5}
}

#declare greebleMat2 =
material {
        MetalMatG (<1,1,1>*0.4)
        interior {ior 1.5}
}

#declare greebleMat3 =
material {
        MetalMatG (<1,1,1>*0.4)
        interior {ior 1.5}
} 

#macro MetalMatG2 (Color)

texture {
	aoi
	texture_map {
		[0      pigment {color srgb Color*1.5} 
		        normal {
		                average
		                normal_map {
		                        [1      pigment_pattern {norm_cyl}
        	                        	0.2
        	                        	triangle_wave
        	                        	accuracy 0.001
                                        ]
                                        [1      spotted 0.4 scale 0.0001]
                                
                                }
                        }
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	emission 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {srgb Color}
	                	irid {
        			        0.1
        			        thickness 0.2
        			        turbulence 1
        		        }	                	
	                }
                ]
                [0.4    pigment {color srgb 0}
		        normal {
		                average
		                normal_map {
		                        [1      pigment_pattern {norm_cyl}
        	                        	0.2
        	                        	triangle_wave
        	                        	accuracy 0.001
                                        ]
                                        [1      spotted 0.1 scale 0.0001]
                                
                                }
                        }
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {0, 1}
	                }
                ]
                [0.6    pigment {color srgb 0} 
		        normal {
		                average
		                normal_map {
		                        [1      pigment_pattern {norm_cyl}
        	                        	0.2
        	                        	triangle_wave
        	                        	accuracy 0.001
                                        ]
                                        [1      spotted 0.1 scale 0.0001]
                                
                                }
                        }
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {0, 1}
	                }
                ]
		[1      pigment {color srgb Color*1.5}
		        normal {
		                average
		                normal_map {
		                        [1      pigment_pattern {norm_cyl}
        	                        	0.2
        	                        	triangle_wave
        	                        	accuracy 0.001
                                        ]
                                        [1      spotted 0.4 scale 0.0001]
                                
                                }
                        }
	                finish {
	                	brilliance 4
	                	diffuse 0
	                	emission 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {srgb Color}
	                	irid {
        			        0.1
        			        thickness 0.2
        			        turbulence 1
        		        }
	                }
                ]
	}        
}

#end 

#declare hullplain = 
union {
        difference {
                sphere {<0,0,0>, 10 scale <2.5,0.6,5>}
                box {<-7,-15,-90>, <7,15,-38>}
                box {<-8,-15,-90>, <8,15,-40>}
                box {<-40,-15,90>, <40,15,0>}
        }
        difference {
                sphere {<0,0,0>, 10 rotate 5*x scale <2.1,0.5,3>}
                box {<-40,-15,90>, <40,15,20>}
                translate <0,1.5,0>  
        }
        difference {
                sphere {<0,0,0>, 10 rotate 5*x scale <1.8,0.5,3>}
                box {<-40,-15,90>, <40,15,20>}
                translate <0,1.5,8>
        }
        difference {
                sphere {<0,0,0>, 10 rotate 5*x scale <1.4,0.5,3>}
                box { <-40,-15,90>, <40,15,15>}
                translate <0,1.5,16>
        }
        cone   {<0,5,-8>, 10, <0,6.5,-8>, 9}
}

#declare hullcut = 
union {
        difference {
                object {hullplain}
                box {<-4,-10,-5>, <4,10,4> translate <15,0,-40>}
                box {<-4,-10,-4>, <4,10,4> translate <18,0,-35>}
                box {<-1.5,-10,-35>, <0,10,35> translate <10,0,-15>}
                box {<-4,-10,-5>, <4,10,4> translate <-15,0,-40>}
                box {<-4,-10,-4>, <4,10,4> translate <-18,0,-35>}
                box {<-1.5,-10,-35>, <0,10,35> translate <-10,0,-15>}
                prism {                                
                        cubic_spline 
                        -10, 10, 8,
                        <-2, 1>, 
                        < 2, 1>, 
                        < 2,-2>, 
                        < 0,-3>, 
                        <-2,-2>, 
                        <-2, 1>,
                        < 2, 1>, 
                        <-2, 1> 
                        scale <3,3,3>
                        translate <0,0,-25> 
                }
                prism {                                
                        cubic_spline 
                        -10, 10, 8,
                        <-2, 1>, 
                        < 2, 1>, 
                        < 2,-2>, 
                        < 0,-3>, 
                        <-2,-2>, 
                        <-2, 1>,
                        < 2, 1>, 
                        <-2, 1> 
                        scale <5,4,-4>
                        translate <0,0,15> 
                }
        }
}

#declare hull = 
difference {
        union {
                object {
                        hullcut 
                        material {
                                MetalMatG2 (<0.5,0.5,0.5>)
                                interior {ior 1.5} 
                                rotate x*90
                                scale 50
                                translate <0,0,-8>
                        }
                }
                object {
                        hullplain 
                        scale <0.97,0.85,0.98> 
                        material {
                                MetalMatG2 (<0.5,0.5,0.5>)
                                interior {ior 1.5} 
                                rotate x*90
                                scale 50
                                translate <0,0,-8>
                        }
                }
                prism {                                
                        linear_spline 
                        0, 6.5, 5,
                        <-2, 1>, 
                        < 2, 1>, 
                        < 1,-2>, 
                        <-1,-2>, 
                        <-2, 1>
                        scale <4.5,1,-9>
                        translate <0,0,2>
                }
                union {
                        #declare q = 0;
                        #while (q < 10)
                                object {
                                        LED_ (<1.2,0,0.24>) 
                                        scale <1,1,1>*1.4  
                                        translate <0,3.6,20> 
                                        rotate <0,q*36+18,0>
                                }
                                #declare q = q+1;
                        #end 
                        rotate x*-2
                        translate <0,0,-8>
                }
                union {
                        #declare q = 0;
                        #while (q < 10)
                                object {
                                        LED_ (<1.2,0.6,0>) 
                                        scale <1,1,1>*1.4  
                                        translate <0,5,10> 
                                        rotate <0,q*36,0>
                                }
                                #declare q = q+1;
                        #end 
                        rotate x*-2
                        translate <0,0,-8>
                }                
        }
        cone {
                <0,6.1,-8>, 8, <0,8,-8>, 10
                material {
                        MetalMatG2 (0.25+0.25*<0,0.5,0.5>)
                        interior {ior 1.5} 
                        rotate x*90
                        scale 50
                        translate <0,0,-8>
                }
        }
        cone   { 
                <0,5.5,-8>, 6, <0,8,-8>, 8
                material {
                        MetalMatG2 (0.25+0.25*<1,0.1,0>)
                        interior {ior 1.5} 
                        rotate x*90
                        scale 50
                        translate <0,0,-8>
                }  
        }
}

#declare bridgeplain = 
union {
        intersection {
                difference {
                        cylinder {<6,-20,20>, <-6,-20,20>, 40} 
                        cylinder {<8,-27,20>, <-8,-27,20>,40}
                        box {<-15,30,20>, <15,-30,70>}
                        box {<-15,30,3>, <15,-30,-50>}
                        box {<-5,-5,50>, <5,5,-50> rotate 70*z rotate -20*x rotate 3*y translate <9,8,0>}
                        box {<-5,-5,50>, <5,5,-50> rotate -70*z rotate -20*x rotate -3*y translate <-9,8,0>}
                        box {<-10,-10,10>, <10,10,-10> rotate -60*x translate <0,7,-3>}
                        box {<-10,-10,10>, <10,10,-10> rotate 30*x translate <0,15,-8.8>}
                        box {<-10,-10,10>, <10,10,-10> rotate 30*x translate <0,15,30> }
                        box {<-10,-10,10>, <10,10,-10> translate <0,3,10>}
                }         
                cone {<-7,-20,18>, 48, <12,-20,18>, 32 rotate 5*y}
                cone {<7,-20,18>, 48, <-12,-20,18>, 32 rotate -5*y}
        }
        translate <0,-15,-10>
        rotate -15*x    
}

#declare bridgecut = 
difference {
        object {bridgeplain}
        box {<-3,-10,-5>, <3,10,5>}
}

#declare bridge = 
union {
        object {bridgecut}
        object {
                bridgeplain scale <0.9,0.85,0.9> 
                material {
                        MetalMatG2 (<0.5,0.5,0.5>)
                        interior {ior 1.5} 
                        rotate x*90
                        scale 50
                        translate <0,0,-8>
                }
        }  
}

#declare lozenge01 =  
blob {
        threshold 0.9 
        sphere {<-4,0,0>, 7, 1 scale <1,1,10>}
        sphere {<-2,0,0>, 6.8, 1 scale <1,1,10>}
        sphere {<0,0,0>, 6.6, 1 scale <1,1,10>}
        sphere {<2,0,0>, 6.4, 1 scale <1,1,10>}
        sphere {<3,0,0>, 6, 1 scale <1,1,10>}
}

#declare lozenge02 = 
difference {
        object {lozenge01}
        box {<-100,-100,-50>, <100,100,-10> rotate -40*y}
        box {<-100,-100,50>, <100,100,10>}
        scale <1.2,1,1>
}

#declare lozenge02a = 
difference {
        difference {
                object {lozenge01}
                box {<-10,-10,-50>, <10,10,-10> rotate -40*y}
                box {<-10,-10,50>, <10,10,15>}
                scale <1.2,1,1>
        }
        box {<-10,-10,-50>, <-5,10,50>}
}
    
#declare lozenge03 = 
difference {
        object {lozenge02}
        object {
                lozenge02a 
                scale <0.9,0.85,1.1> 
                material {
                        MetalMatG2 (<0.5,0.5,0.5>)
                        interior {ior 1.5} 
                        rotate x*90
                        scale 50
                        translate <0,0,-8>
                }
        } 
}

#declare engine01 = 
union {
        difference {
                union {
                        object {lozenge03}
                        object {
                                lozenge03 
                                scale <0.6,0.6,0.75> 
                                material {
                                        MetalMatG (<0.5,0.5,0.5>)
                                        interior {ior 1.5} 
                                        rotate x*90
                                        scale 50
                                        translate <0,0,-8>
                                }
                        }
                }
                box {<-15,-20,-50>, <-7,20,50>} 
        }
}

#declare landing = 
union {
        object {
                hull 
                material {
                        MetalMatG2 (<0.5,0.5,0.5>)
                        interior {ior 1.5} 
                        rotate x*90
                        scale 50
                        translate <0,0,-8>
                }
        }
        object {
                bridge 
                scale <1.2,1,1.5> 
                translate <0,-4.1,-49>  
                material {
                        MetalMatG (<0.5,0.5,0.5>)       
                        interior {ior 1.5} 
                        rotate x*90
                        scale 10
                        translate <0,0,-8>
                } 
        }
        object {
                engine01
                scale <1.4,1.2*0.9,1.6>
                rotate -10*z 
                rotate -15*y 
                translate <22,-1,0>
                material {
                        MetalMatG2 (<0.5,0.5,0.5>)
                        interior {ior 1.5} 
                        rotate x*90
                        scale 50
                        translate <0,0,-8>
                }
        }
        object {
                engine01
                scale <-1.4,1.2*0.9,1.6>
                rotate 10*z 
                rotate 15*y 
                translate <-22,-1,0>
                material {
                        MetalMatG2 (<0.5,0.5,0.5>)
                        interior {ior 1.5} 
                        rotate x*90
                        scale 50
                        translate <0,0,-8>
                }
        }  
}

object {
        landing
        scale 0.003
        translate <0,-0.047,0.04>
        rotate <0,180,0> 
        rotate <0,90,90>
        rotate y*-90
        translate y*1.05
        rotate x*90
        rotate y*(6*36-18) 
        translate <0,0.35,-1.5> 
}

//____________________________________________________________________________________________

#declare toralball = 
union {
        torus {8, 0.5}
        torus {8, 0.5 rotate 90*z}
        torus {8, 0.5 rotate 90*x}
        rotate 45*y 
        rotate 45*x 
        rotate 45*z 
}

#declare toralstrutsect = 
union {
        object {toralball}
        cylinder {<0,0,-8>, <0,0,8>, 3} 
}

#declare toralstrut40 = 
union {
        object {toralstrutsect}
        object {toralstrutsect translate   8*z}
        object {toralstrutsect translate  -8*z}
        object {toralstrutsect translate  16*z}
        object {toralstrutsect translate -16*z}
        object {toralstrutsect translate  24*z}
        object {toralstrutsect translate -24*z}
        object {toralstrutsect translate  32*z}
        object {toralstrutsect translate -32*z}
        object {toralstrutsect translate  40*z}
        object {toralstrutsect translate -40*z}
}

#declare webstrutquart =
union {
        torus {50, 3 rotate 90*x translate 60*z}
        torus {50, 3 rotate 75*x translate 60*z}
        torus {50, 3 rotate 60*x translate 60*z}
        torus {50, 3 rotate 45*x translate 60*z}
        torus {50, 3 rotate 30*x translate 60*z}
        torus {50, 3 rotate 15*x translate 60*z}
}

#declare strutsphere1 = 
union {
        sphere {<0,0,60>, 50}
        object {webstrutquart}
        object {webstrutquart rotate 180*z}
        object {webstrutquart rotate  90*z}
        object {webstrutquart rotate 270*z}    
        torus {49, 3 rotate 45*z translate 60*z}
        torus {49, 3 rotate -45*z translate 60*z}
}

#declare ovalstrutquart = 
union {
        object {toralstrutsect scale 1.25 translate 50*x}
        object {toralstrutsect scale 1.25 rotate  -7*y translate <49,0,8>}
        object {toralstrutsect scale 1.25 rotate -13*y translate <48,0,16>}
        object {toralstrutsect scale 1.25 rotate -17*y translate <47,0,24>}
        object {toralstrutsect scale 1.25 rotate -22*y translate <45,0,32>}
        object {toralstrutsect scale 1.25 rotate -26*y translate <42,0,40>}
        object {toralstrutsect scale 1.25 rotate -30*y translate <39,0,46>}
        object {toralstrutsect scale 1.25 rotate -37*y translate <35,0,53>}
        object {toralstrutsect scale 1.25 rotate -45*y translate <30,0,59>}
        object {toralstrutsect scale 1.25 rotate -53*y translate <22,0,66>}
        object {toralstrutsect scale 1.25 rotate -60*y translate <14,0,71>}
        object {toralstrutsect scale 1.25 rotate -70*y translate <7,0,74>}
        object {toralstrutsect scale 1.25 rotate -90*y translate <0,0,75>}
} 

#declare ovalstrutoval = 
union {
        object {ovalstrutquart}
        object {ovalstrutquart rotate 180*z}
        object {ovalstrutquart rotate 180*x}
        object {ovalstrutquart rotate 180*z rotate 180*x}
}

#declare engine01 = 
union { 
        sphere {<0,0,0>, 12}
        sphere {<0,10,0>, 8}
        cylinder {<4,16,4>, <12,-6,12>, 1} 
        cylinder {<-4,16,4>, <-12,-6,12>, 1} 
        cylinder {<4,16,-4>, <12,-6,-12>, 1} 
        cylinder {<-4,16,-4>, <-12,-6,-12>, 1} 
        sphere {<4,16,4>, 2} 
        sphere {<-4,16,4>, 2} 
        sphere {<4,16,-4>, 2} 
        sphere {<-4,16,-4>, 2}
        cylinder {<0,10,0>, <16,-8,0>, 2}  
        cylinder {<0,10,0>, <0,-8,16>, 2}
        cylinder {<0,10,0>, <-16,-8,0>, 2}
        cylinder {<0,10,0>, <0,-8,-16>, 2}
        cone {<16,-4,0>, 0.5, <16,-12,0>, 4 open}
        cone {<-16,-4,0>, 0.5, <-16,-12,0>, 4 open}
        cone {<0,-4,16>, 0.5, <0,-12,16>, 4 open}
        cone {<0,-4,-16>, 0.5, <0,-12,-16>, 4 open}
        cylinder {<4,18,4>, < 16,-4,0>, 0.5} 
        cylinder {<4,18,-4>, < 16,-4,0>, 0.5}  
        cylinder {<-4,18,4>, <-16,-4,0>, 0.5} 
        cylinder {<-4,18,-4>, <-16,-4,0>, 0.5}
        cylinder {<4,18,4>, <0,-4,16>, 0.5}
        cylinder {<-4,18,4>, <0,-4,16>, 0.5}
        cylinder {<4,18,-4>, <0,-4,-16>, 0.5}
        cylinder {<-4,18,-4>, <0,-4,-16>, 0.5} 
        lathe { 
                cubic_spline 
                10, 
                <0,0>,
                <5,-5>,
                <10,-10>, 
                <10,-12>, 
                <12,-16>, 
                <12,-16>, 
                <10,-12>,
                <10,-10>, 
                <5,-5>, 
                <0,0>
        } 
        torus {17, 1 translate <0,-6,0>}
        translate -16*y
        rotate -90*x 
}

#declare bigengine01 = 
union {
        object {strutsphere1 translate <0,0,-60> scale <0.65,0.65,2.5> scale 0.4 rotate 33*y translate <30,0,50>}
        object {strutsphere1 translate <0,0,-60> scale <0.65,0.65,2.5> scale 0.4 rotate -33*y translate <-30,0,50>}
        object {strutsphere1 translate <0,0,-60> scale <0.65,0.65,2.5> scale 0.4 rotate 33*y translate <30,0,50> rotate 90*z}
        object {strutsphere1 translate <0,0,-60> scale <0.65,0.65,2.5> scale 0.4 rotate 33*y translate <30,0,50> rotate -90*z}
        difference {
                object {strutsphere1 scale <0.9,0.9,1.1> translate 5*z}
                sphere {<0,0,60>, 50 scale <0.85,0.85,1.1> translate 18*z}
        }
        object {engine01 rotate -15*x translate <0,55,90>}
        object {engine01 rotate 15*x translate <0,-55,90>}
        object {engine01 rotate 15*y translate <55,0,90>}
        object {engine01 rotate -15*y translate <-55,0,90>}
}

#declare pole = 
union {
        object {ovalstrutoval rotate 30*z scale 0.65*<1,2,1> rotate <0,90,0> translate <0,-40,-62>}
        object {toralstrut40 scale <1.5,1.5,2> translate -40*z}         
        object {ovalstrutoval scale 0.8*y}
        object {ovalstrutoval rotate 90*z scale 0.8*y}
        object {ovalstrutoval scale 0.75 scale 0.8*y translate -100*z}
        object {ovalstrutoval rotate 90*z scale 0.75 scale 0.8*y translate -100*z}
        object {strutsphere1 translate <0,0,-240> scale <0.4,0.4,0.85>}
        object {strutsphere1 translate <0,0,-160> scale <0.4,0.4,0.85>}
        object {strutsphere1 translate <0,0,-80> scale <0.4,0.4,0.85>}
        object {strutsphere1 scale <0.4,0.4,0.85>} 
        object {toralball scale 2.8 translate 10*z}
        object {toralball scale 3.8 translate 28*z}
        object {engine01 scale 0.75*<1,1,1> rotate  135*y translate <15,0,-160>}
        object {engine01 scale 0.75*<1,1,1> rotate -135*y translate <-15,0,-160>}
        object {engine01 scale 0.75*<1,1,1> rotate  135*x translate <0,-15,-160>}
        object {engine01 scale 0.75*<1,1,1> rotate -135*x translate <0,15,-160>}  
        union {
                object {engine01 scale 0.6*<1,1,1> rotate  135*y translate <15,0,-160>}
                object {engine01 scale 0.6*<1,1,1> rotate -135*y translate <-15,0,-160>}
                object {engine01 scale 0.6*<1,1,1> rotate  135*x translate <0,-15,-160>}
                object {engine01 scale 0.6*<1,1,1> rotate -135*x translate <0,15,-160>}
                object {engine01 scale 0.55*<1,1,1> rotate  155*y translate <5,0,-185>}
                object {engine01 scale 0.55*<1,1,1> rotate -155*y translate <-5,0,-185>}
                object {engine01 scale 0.55*<1,1,1> rotate  155*x translate <0,-5,-185>}
                object {engine01 scale 0.55*<1,1,1> rotate -155*x translate <0,5,-185>} 
                rotate z*45
        }
        object {toralball scale 1.5 translate -192*z}
        object {toralstrut40 scale 1.3 rotate 90*y translate -50*z}
        object {strutsphere1 scale <0.35,0.1,0.4> translate <65,0,-70>}
        object {strutsphere1 scale <0.35,0.1,0.4> translate <-65,0,-70>}
        material {
                MetalMatG (<0.5,0.5,0.5>)                            
                interior {ior 1.5}
                scale 30
        }
}

object {
        pole
        translate y*150 
        scale 0.0014
        rotate <0,90,-50>
        rotate y*-90
        translate y*0.92
        rotate x*90
        rotate y*(6*36-18) 
        translate <0,0.35,-1.5> 
}

//____________________________________________________________________________________________

#include "ship.inc"

object {
        shuttle (1)
        scale 0.04*<1,0.7,1>
        rotate <0,70,0> 
        rotate <0,90,90>
        rotate y*-90
        translate y*1.03
        rotate x*90
        rotate y*(6*36-17) 
        translate <0,0.35,-1.5> 
}

object {
        shuttle (0)
        scale 0.04*<1,0.7,1>
        rotate z*-20
        rotate y*40
        rotate x*30
        translate <0.7,1.77,-4.68>
}

#end 

//_______________________________________________________________________________________

#if (sparks)

// ELECTRICITY                                                                                        // Rune Skovbo Johansen  Electricity Include File  http://runevision.com/3d/include/  
// ****************************************
// Copyright 2001 Rune S. Johansen
   
// The output is a point that moves from PointA to PointB as Value goes from 0 to 1
#macro LinearPath (PointA, PointB, Value)

(PointA*(1-Value)+PointB*Value)

#end
   
// The output is a color vector that changes from ColorA to Color B as Value goes from 0 to 1
#macro LinearColor (ColorA, ColorB, Value) 

(vnormalize (ColorA*(1-Value)+ColorB*Value)*(vlength (ColorA)*(1-Value)+vlength (ColorB)*Value))

#end
   
// This is the Electric macro. It calls the internal _Electric macro specified further down.
#macro Electric (Brightness, Thickness, Fuzzyness, RollSpeed, FlickerSpeed, MinDist)
      
_Electric (0, 1, ElectricPath (0), ElectricPath (1), 1, -((ElectricPath (0))+(ElectricPath (1)))*100) 
      
#end
   
// This macro is used internally only.
// The user do not need to call this macro.
#macro _Electric (ValueA, ValueB, PointA, PointB, Level, Offset)

#local ValueM = (ValueA+ValueB)*0.5;
#local FlickerClock = int ((clock*FlickerSpeed+vturbulence (0, 0, 0, Offset+FlickerSpeed*z*clock_).y));
#local Turbulence = vturbulence (0, 0, 0, Offset-<100*FlickerClock,RollSpeed*clock_,0>);
#local PointM = ((PointA+PointB)*0.5+(ElectricPath (ValueM))-((ElectricPath (ValueA))+(ElectricPath (ValueB)))*0.5+Turbulence*vlength (PointA-PointB)*Fuzzyness);

//glow {location PointM type 0 color ElectricColor (ValueM)*Brightness #if (Thickness > 0) radius Thickness #end}
                                                                                                        // Megapov glow replaced by Alain - http://news.povray.org/povray.advanced-users/message/%3C526319b7%40news.povray.org%3E/#%3C526319b7%40news.povray.org%3E
sphere {                                                                                                                        // see also http://news.povray.org/povray.advanced-users/message/%3C52626c35%241%40news.povray.org%3E/#%3C52626c35%241%40news.povray.org%3E 
        <0,0,0>, 1 
        pigment {color rgbt 1}
        interior {
                #local M_samples = 15;
                #local M_variance = 0.002;
                media {
                        samples M_samples
                        emission rgb fac*1
                        density {
                                spherical
                                poly_wave 1.5
                                color_map {
                                        [0      rgb 0]
                                        #ifdef (Thickness)
                                                #if(Thickness = 0)                                    
                                                        [0.8    rgb ElectricColor (ValueM)*Brightness*2]
                                                        [0.9    rgb <1,1,1>*Brightness*75]
                                                        [1      rgb <1,1,1>*Brightness*200]
                                                #else                                                  
                                                        [0.8    rgb ElectricColor (ValueM)*Brightness/Thickness]
                                                        [0.9    rgb <1,1,1>*Brightness/Thickness]
                                                        [1      rgb <1,1,1>*Brightness/Thickness]
                                                #end
                                        #else                                                           
                                                [0.8    rgb ElectricColor (ValueM)*Brightness*2]
                                                [0.9    rgb <1,1,1>*Brightness*75]
                                                [1      rgb <1,1,1>*Brightness*200]
                                        #end
                                }
                        }
                }
        }
        hollow
        #if (Thickness > 0) 
                scale Thickness  
        #else 
                scale 0.5 
        #end
        translate PointM
}

#if (vlength (PointA-PointM) > MinDist) _Electric (ValueA, ValueM, PointA, PointM, Level+1, Offset+pow (3, Level)*x) #end
#if (vlength (PointB-PointM) > MinDist) _Electric (ValueB, ValueM, PointB, PointM, Level+1, Offset+pow (3, Level)*y) #end  
        
#end

#macro ElectricPath (V) 

LinearPath (<-4.05886,0.93634,1.34017>, <-3.97936,0.90229,1.47912>, V) 

#end 

#macro ElectricColor (V) 

<0.4,0.7,1> 

#end 

#declare clock_ = 0;
//        Brightness, Thickness, Fuzzyness RollSpeed FlickerSpeed MinDist
Electric (1,          0.004,     0.6,      5,        10,          0.002)        // left spark

#macro ElectricPath (V) 

LinearPath (<3.19256,0.91093,2.46873>, <2.7758,0.90985,2.75834>, V) 

#end 

#macro ElectricColor (V) 

<0.3,0.5,1> 

#end 

#declare clock_ = 0.5;
//        Brightness, Thickness, Fuzzyness RollSpeed FlickerSpeed MinDist
Electric (1,          0.004,     0.6,      5,        10,          0.002)        // right spark
   
#end